@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -23,7 +23,6 @@
 #ifndef KADDRESSBOOK_PART_H
 #define KADDRESSBOOK_PART_H
 
-#include <kparts/browserextension.h>
 #include <kparts/event.h>
 #include <kparts/factory.h>
 #include <kparts/part.h>
@@ -31,7 +30,6 @@
 #include "kaddressbookiface.h"
 
 class KAboutData;
-class KAddressbookBrowserExtension;
 class KInstance;
 
 class KABCore;
@@ -64,18 +62,6 @@ class KAddressbookPart: public KParts::ReadOnlyPart, virtual public KAddressBook
 
   private:
     KABCore *mCore;
-    KAddressbookBrowserExtension *mExtension;
-};
-
-class KAddressbookBrowserExtension : public KParts::BrowserExtension
-{
-  Q_OBJECT
-
-  friend class KAddressbookPart;
-
-  public:
-    KAddressbookBrowserExtension( KAddressbookPart *parent );
-    virtual ~KAddressbookBrowserExtension();
 };
 
 #endif
