@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -36,7 +36,6 @@
 #include <qstringlist.h>
 #include <qvaluelist.h>
 
-#include "undo.h"
 #include "kaddressbookview.h"
 
 class QListViewItem;
@@ -69,14 +68,14 @@ friend class ContactListView;
                            const char *name = 0 );
     virtual ~KAddressBookTableView();
 
-    virtual void refresh(QString uid = QString::null);
+    virtual void refresh( const QString &uid = QString() );
     virtual QStringList selectedUids();
-    virtual void setSelected(QString uid = QString::null, bool selected = false);
+    virtual void setSelected( const QString &uid = QString(), bool selected = false );
     virtual void setFirstSelected( bool selected = true );
     virtual KABC::Field *sortField() const;
 
-    virtual void readConfig(KConfig *config);
-    virtual void writeConfig(KConfig *config);
+    virtual void readConfig( KConfig *config );
+    virtual void writeConfig( KConfig *config );
     virtual QString type() const { return "Table"; }
 
     void scrollUp();
@@ -95,7 +94,7 @@ friend class ContactListView;
       Called whenever the user executes an addressee. In terms of the
       list view, this is probably a double click
     */
-    void addresseeExecuted(QListViewItem*);
+    void addresseeExecuted( QListViewItem* );
 
     /**
       RBM menu called.
@@ -108,7 +107,7 @@ friend class ContactListView;
     void updatePresence( const QString &uid );
 
   private:
-    QVBoxLayout *mainLayout;
+    QVBoxLayout *mMainLayout;
     ContactListView *mListView;
     KIMProxy *mIMProxy;
 };
