@@ -1,7 +1,7 @@
 /*
  *  alarmcalendar.h  -  KAlarm calendar file access
  *  Program:  kalarm
- *  (C) 2001 - 2004 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright (c) 2001 - 2005 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,9 +13,9 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef ALARMCALENDAR_H
@@ -26,6 +26,8 @@
 #include <libkcal/calendarlocal.h>
 #include "alarmevent.h"
 
+class KConfig;
+
 
 /** Provides read and write access to calendar files.
  *  Either vCalendar or iCalendar files may be read, but the calendar is saved
@@ -45,11 +47,10 @@ class AlarmCalendar : public QObject
 		void                  close();
 		void                  startUpdate();
 		void                  endUpdate();
-		KCal::Event*          event(const QString& uniqueID)      { return mCalendar ? mCalendar->event(uniqueID) : 0; }
-		KCal::Event::List     events()                            { return mCalendar->events(); }
-		KCal::Event::List     events(const QDate& d, bool sorted = false) { return mCalendar->events(d, sorted); }
+		KCal::Event*          event(const QString& uniqueID);
+		KCal::Event::List     events();
 		KCal::Event::List     eventsWithAlarms(const QDateTime& from, const QDateTime& to);
-		KCal::Event*          addEvent(const KAEvent&, bool useEventID = false);
+		KCal::Event*          addEvent(KAEvent&, bool useEventID = false);
 		void                  updateEvent(const KAEvent&);
 		void                  deleteEvent(const QString& eventID, bool save = false);
 		void                  emitEmptyStatus();
@@ -59,10 +60,6 @@ class AlarmCalendar : public QObject
 		bool                  isOpen() const                      { return mOpen; }
 		QString               path() const                        { return mUrl.prettyURL(); }
 		QString               urlString() const                   { return mUrl.url(); }
-		int                   KAlarmVersion() const               { return mKAlarmVersion; }
-		const QString&        KAlarmSubVersion() const            { return mKAlarmSubVersion; }
-		bool                  KAlarmVersion057_UTC() const        { return mKAlarmVersion057_UTC; }
-		static int            KAlarmVersion(int major, int minor, int rev)  { return major*10000 + minor*100 + rev; }
 
 		static bool           initialiseCalendars();
 		static void           terminateCalendars();
@@ -74,6 +71,7 @@ class AlarmCalendar : public QObject
 		static AlarmCalendar* expiredCalendarOpen()   { return calendarOpen(EXPIRED); }
 		static AlarmCalendar* displayCalendarOpen()   { return calendarOpen(DISPLAY); }
 		static AlarmCalendar* templateCalendarOpen()  { return calendarOpen(TEMPLATE); }
+		static const KCal::Event* getEvent(const QString& uniqueID);
 
 		enum CalID { ACTIVE, EXPIRED, DISPLAY, TEMPLATE, NCALS };
 
@@ -90,11 +88,8 @@ class AlarmCalendar : public QObject
 		              const QString& configKey = QString::null);
 		bool                  create();
 		bool                  saveCal(const QString& newFile = QString::null);
-		void                  convertToICal();
 		void                  purge(int daysToKeep);
 		void                  startPurgeTimer();
-		void                  getKAlarmVersion() const;
-		bool                  isUTC() const;
 		static AlarmCalendar* createCalendar(CalID, KConfig*, QString& writePath, const QString& configKey = QString::null);
 		static AlarmCalendar* calendarOpen(CalID);
 
@@ -107,9 +102,6 @@ class AlarmCalendar : public QObject
 		QString               mConfigKey;          // config file key for this calendar's URL
 		KAEvent::Status       mType;               // what type of events the calendar file is for
 		int                   mPurgeDays;          // how long to keep alarms, 0 = don't keep, -1 = keep indefinitely
-		mutable int           mKAlarmVersion;      // version of KAlarm which created the loaded calendar file
-		mutable QString       mKAlarmSubVersion;   // sub-version of KAlarm which created the loaded calendar file
-		mutable bool          mKAlarmVersion057_UTC; // calendar file was created by KDE 3.0.0 KAlarm 0.5.7
 		bool                  mOpen;               // true if the calendar file is open
 		int                   mPurgeDaysQueued;    // >= 0 to purge the calendar when called from KAlarmApp::processLoop()
 		int                   mUpdateCount;        // nesting level of group of calendar update calls
