@@ -1,7 +1,7 @@
 /*
  *  dcophandler.h  -  handler for DCOP calls by other applications
  *  Program:  kalarm
- *  (C) 2001, 2002, 2004 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright  2001,2002,2004-2006 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,8 +14,8 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef DCOPHANDLER_H
@@ -67,27 +67,29 @@ class DcopHandler : public QWidget, virtual public KAlarmIface
 	virtual bool scheduleEmail(const QString& fromID, const QString& addresses, const QString& subject, const QString& message,
 	                           const QString& attachments, const QString& startDateTime, int lateCancel, unsigned flags,
 	                           int recurType, int recurInterval, const QString& endDateTime);
+	virtual bool edit(const QString& eventID);
+	virtual bool editNew(const QString& templateName);
 
     private:
 	static bool scheduleMessage(const QString& message, const DateTime& start, int lateCancel, unsigned flags,
                                 const QString& bgColor, const QString& fgColor, const QString& fontStr,
-                                const KURL& audioFile, int reminderMins, const KCal::Recurrence&,
+                                const KURL& audioFile, int reminderMins, const KARecurrence&,
 	                            int repeatInterval = 0, int repeatCount = 0);
 	static bool scheduleFile(const KURL& file, const DateTime& start, int lateCancel, unsigned flags, const QString& bgColor,
-                             const KURL& audioFile, int reminderMins, const KCal::Recurrence&,
+                             const KURL& audioFile, int reminderMins, const KARecurrence&,
 	                         int repeatInterval = 0, int repeatCount = 0);
 	static bool scheduleCommand(const QString& commandLine, const DateTime& start, int lateCancel, unsigned flags,
-                                const KCal::Recurrence&, int repeatInterval = 0, int repeatCount = 0);
+                                const KARecurrence&, int repeatInterval = 0, int repeatCount = 0);
 	static bool scheduleEmail(const QString& fromID, const QString& addresses, const QString& subject, const QString& message,
                               const QString& attachments, const DateTime& start, int lateCancel, unsigned flags,
-                              const KCal::Recurrence&, int repeatInterval = 0, int repeatCount = 0);
+                              const KARecurrence&, int repeatInterval = 0, int repeatCount = 0);
 	static DateTime  convertStartDateTime(const QString& startDateTime);
 	static unsigned  convertStartFlags(const DateTime& start, unsigned flags);
 	static QColor    convertBgColour(const QString& bgColor);
-	static bool      convertRecurrence(DateTime& start, KCal::Recurrence&, const QString& startDateTime, const QString& icalRecurrence);
-	static bool      convertRecurrence(DateTime& start, KCal::Recurrence&, const QString& startDateTime, int recurType, int recurInterval, int recurCount);
-	static bool      convertRecurrence(DateTime& start, KCal::Recurrence&, const QString& startDateTime, int recurType, int recurInterval, const QString& endDateTime);
-	static bool      convertRecurrence(KCal::Recurrence&, const DateTime& start, int recurType, int recurInterval, int recurCount, const QDateTime& end);
+	static bool      convertRecurrence(DateTime& start, KARecurrence&, const QString& startDateTime, const QString& icalRecurrence);
+	static bool      convertRecurrence(DateTime& start, KARecurrence&, const QString& startDateTime, int recurType, int recurInterval, int recurCount);
+	static bool      convertRecurrence(DateTime& start, KARecurrence&, const QString& startDateTime, int recurType, int recurInterval, const QString& endDateTime);
+	static bool      convertRecurrence(KARecurrence&, const DateTime& start, int recurType, int recurInterval, int recurCount, const QDateTime& end);
 };
 
 
