@@ -1,7 +1,7 @@
 /*
  *  functions.cpp  -  miscellaneous functions
  *  Program:  kalarm
- *  Copyright (c) 2001-2006 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright  2001-2006 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -312,9 +312,10 @@ UpdateStatus deleteEvent(KAEvent& event, bool archive)
 		if (event.copyToKOrganizer())
 		{
 			// The event was shown in KOrganizer, so tell KOrganizer to
-			// delete it. But ignore errors, because the user could have
+			// delete it. Note that an error could occur if the user
 			// manually deleted it from KOrganizer since it was set up.
-			deleteFromKOrganizer(event.id());
+			if (!deleteFromKOrganizer(event.id()))
+				ret = UPDATE_KORG_ERR;
 		}
 		if (archive  &&  event.toBeArchived())
 			addExpiredEvent(event);     // this changes the event ID to an expired ID
@@ -437,26 +438,81 @@ void enableEvent(KAEvent& event, AlarmListView* selectionView, bool enable)
 /******************************************************************************
 * Display an error message corresponding to a specified alarm update error code.
 */
-void displayUpdateError(QWidget* parent, UpdateError code, bool multipleAlarms)
+void displayKOrgUpdateError(QWidget* parent, UpdateError code, int nAlarms)
 {
 	QString errmsg;
 	switch (code)
 	{
 		case KORG_ERR_ADD:
-			errmsg = multipleAlarms ? i18n("Unable to show alarms in KOrganizer")
-			                        : i18n("Unable to show alarm in KOrganizer");
+			errmsg = (nAlarms > 1) ? i18n("Unable to show alarms in KOrganizer")
+			                       : i18n("Unable to show alarm in KOrganizer");
 			break;
 		case KORG_ERR_MODIFY:
 			errmsg = i18n("Unable to update alarm in KOrganizer");
 			break;
 		case KORG_ERR_DELETE:
-			errmsg = multipleAlarms ? i18n("Unable to delete alarms from KOrganizer")
-			                        : i18n("Unable to delete alarm from KOrganizer");
+			errmsg = (nAlarms > 1) ? i18n("Unable to delete alarms from KOrganizer")
+			                       : i18n("Unable to delete alarm from KOrganizer");
 			break;
 	}
 	KMessageBox::error(parent, errmsg);
 }
 
+/******************************************************************************
+* Display the alarm edit dialogue to edit a specified alarm.
+*/
+bool edit(const QString& eventID)
+{
+	AlarmCalendar* cal;
+	switch (KAEvent::uidStatus(eventID))
+	{
+		case KAEvent::ACTIVE:
+			cal = AlarmCalendar::activeCalendar();
+			break;
+		case KAEvent::TEMPLATE:
+			cal = AlarmCalendar::templateCalendarOpen();
+			break;
+		default:
+			kdError(5950) << "KAlarm::edit(" << eventID << "): event not active or template" << endl;
+			return false;
+	}
+	KCal::Event* kcalEvent = cal->event(eventID);
+	if (!kcalEvent)
+	{
+		kdError(5950) << "KAlarm::edit(): event ID not found: " << eventID << endl;
+		return false;
+	}
+	KAEvent event(*kcalEvent);
+	MainWindow::executeEdit(event);
+	return true;
+}
+
+/******************************************************************************
+* Display the alarm edit dialogue to edit a new alarm, optionally preset with
+* a template.
+*/
+bool editNew(const QString& templateName)
+{
+	bool result = true;
+	if (!templateName.isEmpty())
+	{
+		AlarmCalendar* cal = AlarmCalendar::templateCalendarOpen();
+		if (cal)
+		{
+			KAEvent templateEvent = KAEvent::findTemplateName(*cal, templateName);
+			if (templateEvent.valid())
+			{
+				MainWindow::executeNew(templateEvent);
+				return true;
+			}
+			kdWarning(5950) << "KAlarm::editNew(" << templateName << "): template not found" << endl;
+		}
+		result = false;
+	}
+	MainWindow::executeNew();
+	return result;
+}
+
 /******************************************************************************
 *  Returns a list of all alarm templates.
 *  If shell commands are disabled, command alarm templates are omitted.
