@@ -1,7 +1,7 @@
 /*
  *  functions.h  -  miscellaneous functions
  *  Program:  kalarm
- *  Copyright (C) 2004, 2005 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright  2004-2006 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,7 +24,6 @@
 /**  @file functions.h - miscellaneous functions */
 
 #include <qsize.h>
-#include <qptrlist.h>
 #include <qstring.h>
 
 #include "alarmevent.h"
@@ -52,7 +51,7 @@ enum UpdateStatus {
 	UPDATE_ERROR,       // update failed completely
 	UPDATE_KORG_ERR     // update succeeded, but KOrganizer update failed
 };
-/** Error codes supplied as parameter to displayUpdateError() */
+/** Error codes supplied as parameter to displayKOrgUpdateError() */
 enum UpdateError { KORG_ERR_ADD, KORG_ERR_MODIFY, KORG_ERR_DELETE };
 
 
@@ -68,6 +67,8 @@ inline int          Version(int major, int minor, int rev)     { return major*10
 int                 getVersionNumber(const QString& version, QString* subVersion = 0);
 QString             browseFile(const QString& caption, QString& defaultDir, const QString& initialFile = QString::null,
                                const QString& filter = QString::null, int mode = 0, QWidget* parent = 0, const char* name = 0);
+bool                edit(const QString& eventID);
+bool                editNew(const QString& templateName = QString::null);
 /** Create a "New Alarm" KAction */
 KAction*            createNewAlarmAction(const QString& label, QObject* receiver, const char* slot, KActionCollection*, const char* name);
 /** Create a "New From Template" KAction */
@@ -93,7 +94,7 @@ void                deleteTemplate(const KAEvent&);
 void                deleteDisplayEvent(const QString& eventID);
 UpdateStatus        reactivateEvent(KAEvent&, AlarmListView* selectionView, bool useEventID = false);
 void                enableEvent(KAEvent&, AlarmListView* selectionView, bool enable);
-void                displayUpdateError(QWidget* parent, UpdateError, bool multipleAlarms = false);
+void                displayKOrgUpdateError(QWidget* parent, UpdateError, int nAlarms);
 
 QString             stripAccel(const QString&);
 
