@@ -1,7 +1,7 @@
 /*
  *  kalarmapp.cpp  -  the KAlarm application object
  *  Program:  kalarm
- *  Copyright (c) 2001 - 2005 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright  2001-2006 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -110,13 +110,11 @@ KAlarmApp::KAlarmApp()
 	Preferences::initialise();
 	Preferences::connect(SIGNAL(preferencesChanged()), this, SLOT(slotPreferencesChanged()));
 	KCal::CalFormat::setApplication(aboutData()->programName(),
-	                          QString::fromLatin1("-//K Desktop Environment//NONSGML KAlarm " KALARM_VERSION "//EN"));
+	                                QString::fromLatin1("-//K Desktop Environment//NONSGML KAlarm " KALARM_VERSION "//EN"));
 	KARecurrence::setDefaultFeb29Type(Preferences::defaultFeb29Type());
 
-	// Check if it's a KDE desktop by comparing the window manager name to "KWin"
-	NETRootInfo nri(qt_xdisplay(), NET::SupportingWMCheck);
-	const char* wmname = nri.wmName();
-	mKDEDesktop = wmname && !strcmp(wmname, "KWin");
+	// Check if the system tray is supported by this window manager
+	mHaveSystemTray = true;   // assume yes in lieu of a test which works
 
 	if (AlarmCalendar::initialiseCalendars())
 	{
@@ -304,7 +302,7 @@ int KAlarmApp::newInstance()
 				// Display only the system tray icon
 				kdDebug(5950)<<"KAlarmApp::newInstance(): tray\n";
 				args->clear();      // free up memory
-				if (!mKDEDesktop)
+				if (!mHaveSystemTray)
 				{
 					exitCode = 1;
 					break;
@@ -362,6 +360,35 @@ int KAlarmApp::newInstance()
 				}
 			}
 			else
+			if (args->isSet("edit"))
+			{
+				QString eventID = args->getOption("edit");
+				if (!initCheck())
+				{
+					exitCode = 1;
+					break;
+				}
+				if (!KAlarm::edit(eventID))
+				{
+					USAGE(i18n("%1: Event %2 not found, or not editable").arg(QString::fromLatin1("--edit")).arg(eventID))
+					exitCode = 1;
+					break;
+				}
+			}
+			else
+			if (args->isSet("edit-new")  ||  args->isSet("edit-new-preset"))
+			{
+				QString templ;
+				if (args->isSet("edit-new-preset"))
+					templ = args->getOption("edit-new-preset");
+				if (!initCheck())
+				{
+					exitCode = 1;
+					break;
+				}
+				KAlarm::editNew(templ);
+			}
+			else
 			if (args->isSet("file")  ||  args->isSet("exec")  ||  args->isSet("mail")  ||  args->count())
 			{
 				// Display a message or file, execute a command, or send an email
@@ -562,6 +589,7 @@ int KAlarmApp::newInstance()
 					if (args->isSet("speak"))
 						USAGE(i18n("%1 incompatible with %2").arg(QString::fromLatin1("--speak")).arg(QString::fromLatin1(audioRepeat ? "--play-repeat" : "--play")))
 					audioFile = args->getOption(audioRepeat ? "play-repeat" : "play");
+#ifndef WITHOUT_ARTS
 					if (args->isSet("volume"))
 					{
 						bool ok;
@@ -570,9 +598,12 @@ int KAlarmApp::newInstance()
 							USAGE(i18n("Invalid %1 parameter").arg(QString::fromLatin1("--volume")))
 						audioVolume = static_cast<float>(volumepc) / 100;
 					}
+#endif
 				}
+#ifndef WITHOUT_ARTS
 				else if (args->isSet("volume"))
 					USAGE(i18n("%1 requires %2 or %3").arg(QString::fromLatin1("--volume")).arg(QString::fromLatin1("--play")).arg(QString::fromLatin1("--play-repeat")))
+#endif
 				if (args->isSet("speak"))
 				{
 					if (args->isSet("beep"))
@@ -961,7 +992,7 @@ bool KAlarmApp::displayTrayIcon(bool show, MainWindow* parent)
 	{
 		if (!mTrayWindow  &&  !creating)
 		{
-			if (!mKDEDesktop)
+			if (!mHaveSystemTray)
 				return false;
 			if (!MainWindow::count()  &&  wantRunInSystemTray())
 			{
@@ -1145,7 +1176,7 @@ void KAlarmApp::slotExpiredPurged()
 */
 bool KAlarmApp::wantRunInSystemTray() const
 {
-	return Preferences::runInSystemTray()  &&  mKDEDesktop;
+	return Preferences::runInSystemTray()  &&  mHaveSystemTray;
 }
 
 /******************************************************************************
