@@ -1,7 +1,7 @@
 /*
- *  kalarmiface.h  -  DCOP interface for KAlarm
+ *  kalarmiface.h  -  DCOP interface to KAlarm
  *  Program:  kalarm
- *  (C) 2004, 2005 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright  2004-2006 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,20 +13,26 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef KALARMIFACE_H
 #define KALARMIFACE_H
 
+/** @file kalarmiface.h - DCOP interface to KAlarm */
+
 // No forward declarations - dcopidl2cpp won't work
 #include <dcopobject.h>
 #include <kurl.h>
 #include <qstringlist.h>
 class QString;
 
+/** KAlarmIface provides a DCOP interface for other applications to request
+ *  KAlarm actions.
+ */
+
 class KAlarmIface : virtual public DCOPObject
 {
 	K_DCOP
@@ -35,25 +41,29 @@ class KAlarmIface : virtual public DCOPObject
 	 *  The bit values may be OR'ed together.
 	 *  @li REPEAT_AT_LOGIN - repeat the alarm at every login.
 	 *  @li BEEP            - sound an audible beep when the alarm is displayed.
+	 *  @li SPEAK           - speak the alarm message when it is displayed.
 	 *  @li REPEAT_SOUND    - repeat the sound file while the alarm is displayed.
 	 *  @li CONFIRM_ACK     - closing the alarm message window requires a confirmation prompt.
 	 *  @li AUTO_CLOSE      - auto-close the alarm window after the late-cancel period.
 	 *  @li SCRIPT          - the command to execute is a script, not a shell command line.
 	 *  @li EXEC_IN_XTERM   - execute the command alarm in a terminal window.
 	 *  @li EMAIL_BCC       - send a blind copy the email to the user.
+	 *  @li SHOW_IN_KORG    - show the alarm as an event in KOrganizer
 	 *  @li DISABLED        - set the alarm status to disabled.
 	 */
 	enum Flags
 	{
 		REPEAT_AT_LOGIN = 0x01,    // repeat alarm at every login
 		BEEP            = 0x02,    // sound audible beep when alarm is displayed
-		CONFIRM_ACK     = 0x04,    // closing the alarm message window requires confirmation prompt
 		REPEAT_SOUND    = 0x08,    // repeat sound file while alarm is displayed
+		CONFIRM_ACK     = 0x04,    // closing the alarm message window requires confirmation prompt
 		AUTO_CLOSE      = 0x10,    // auto-close alarm window after late-cancel period
 		EMAIL_BCC       = 0x20,    // blind copy the email to the user
 		DISABLED        = 0x40,    // alarm is currently disabled
 		SCRIPT          = 0x80,    // command is a script, not a shell command line
-		EXEC_IN_XTERM   = 0x100    // execute command alarm in terminal window
+		EXEC_IN_XTERM   = 0x100,   // execute command alarm in terminal window
+		SPEAK           = 0x200,   // speak the alarm message when it is displayed
+		SHOW_IN_KORG    = 0x400    // show the alarm as an event in KOrganizer
 	};
 	/** Values for the @p repeatType parameter of "scheduleXxxx()" DCOP calls.
 	 *  @li MINUTELY - the repeat interval is measured in minutes.
@@ -167,7 +177,7 @@ class KAlarmIface : virtual public DCOPObject
 	                             const QString& bgColor, const QString& fgColor, const QString& font,
 	                             const KURL& audioFile, int reminderMins,
 	                             int repeatType, int repeatInterval, const QString& endDateTime) = 0;
-
+	
 	/** Schedule a file display alarm.
 	 *  @param file           The text or image file to display.
 	 *  @param startDateTime  Start date/time, in the format YYYY-MM-DD[THH:MM[:SS]] or [T]HH:MM[:SS]
@@ -196,6 +206,8 @@ class KAlarmIface : virtual public DCOPObject
 	 *                        current default background colour. The string may be in any of the formats
 	 *                        accepted by QColor::QColor(const QString&).
 	 *  @param audioFile      The audio file to play when the alarm is displayed, or QString::null for none.
+	 *  @param reminderMins   The number of minutes in advance of the main alarm and its recurrences to display
+	 *                        a reminder alarm, or 0 for no reminder.
 	 *  @param repeatType     The time units to use for recurrence. The actual recurrence interval is equal to 
 	 *                        @p repeatType multiplied by @p repeatInterval.
 	 *                        The value of @p repeatType must a value defined in the RecurType enum.
@@ -214,6 +226,8 @@ class KAlarmIface : virtual public DCOPObject
 	 *                        current default background colour. The string may be in any of the formats
 	 *                        accepted by QColor::QColor(const QString&).
 	 *  @param audioFile      The audio file to play when the alarm is displayed, or QString::null for none.
+	 *  @param reminderMins   The number of minutes in advance of the main alarm and its recurrences to display
+	 *                        a reminder alarm, or 0 for no reminder.
 	 *  @param repeatType     The time units to use for recurrence. The actual recurrence interval is equal to 
 	 *                        @p repeatType multiplied by @p repeatInterval.
 	 *                        The value of @p repeatType must a value defined in the RecurType enum.
@@ -224,7 +238,7 @@ class KAlarmIface : virtual public DCOPObject
 	virtual bool scheduleFile(const KURL& file, const QString& startDateTime, int lateCancel, unsigned flags, const QString& bgColor,
 	                          const KURL& audioFile, int reminderMins,
 	                          int repeatType, int repeatInterval, const QString& endDateTime) = 0;
-
+	
 	/** Schedule a command execution alarm.
 	 *  @param commandLine    The command line or command script to execute.
 	 *  @param startDateTime  Start date/time, in the format YYYY-MM-DD[THH:MM[:SS]] or [T]HH:MM[:SS]
@@ -324,6 +338,18 @@ class KAlarmIface : virtual public DCOPObject
 	virtual bool scheduleEmail(const QString& fromID, const QString& addresses, const QString& subject, const QString& message,
 	                           const QString& attachments, const QString& startDateTime, int lateCancel, unsigned flags,
 	                           int repeatType, int repeatInterval, const QString& endDateTime) = 0;
+	/** Open the alarm edit dialog to edit an existing alarm.
+	 *  @param eventId       The unique ID of the event to be edited, or QString::null to create a new alarm.
+	 *  @return false if the alarm could not be found or is read-only, true otherwise.
+	 */
+	virtual bool edit(const QString& eventID) = 0;
+	/** Open the alarm edit dialog to edit a new alarm.
+	 *  @param templateName  Name of the alarm template to base the new alarm on, or QString::null if none.
+	 *                       If a template is specified but cannot be found, the alarm edit dialog is still
+	 *                       opened but is (obviously) not preset with the template.
+	 *  @return false if an alarm template was specified but could not be found, true otherwise.
+	 */
+	virtual bool editNew(const QString& templateName) = 0;
 };
 
 #endif // KALARMIFACE_H
