@@ -1,7 +1,7 @@
 /*
  *  mainwindow.cpp  -  main application window
  *  Program:  kalarm
- *  Copyright (c) 2001-2006 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright  2001-2006 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -557,7 +557,7 @@ void MainWindow::executeNew(MainWindow* win, const KAEvent* evnt, KAEvent::Actio
 
 		// Add the alarm to the displayed lists and to the calendar file
 		if (KAlarm::addEvent(event, (win ? win->mListView : 0)) == KAlarm::UPDATE_KORG_ERR)
-			KAlarm::displayUpdateError(win, KAlarm::KORG_ERR_ADD);
+			KAlarm::displayKOrgUpdateError(win, KAlarm::KORG_ERR_ADD, 1);
 		Undo::saveAdd(event);
 
 		KAlarm::outputAlarmWarnings(&editDlg, &event);
@@ -608,27 +608,36 @@ void MainWindow::slotModify()
 	if (item)
 	{
 		KAEvent event = item->event();
-		EditAlarmDlg editDlg(false, i18n("Edit Alarm"), this, "editDlg", &event);
-		if (editDlg.exec() == QDialog::Accepted)
+		executeEdit(event, this);
+	}
+}
+
+/******************************************************************************
+*  Open the Edit Alarm dialogue to edit the specified alarm.
+*/
+void MainWindow::executeEdit(KAEvent& event, MainWindow* win)
+{
+	EditAlarmDlg editDlg(false, i18n("Edit Alarm"), win, "editDlg", &event);
+	if (editDlg.exec() == QDialog::Accepted)
+	{
+		KAEvent newEvent;
+		bool changeDeferral = !editDlg.getEvent(newEvent);
+
+		// Update the event in the displays and in the calendar file
+		AlarmListView* view = win ? win->mListView : 0;
+		if (changeDeferral)
 		{
-			KAEvent newEvent;
-			bool changeDeferral = !editDlg.getEvent(newEvent);
-
-			// Update the event in the displays and in the calendar file
-			if (changeDeferral)
-			{
-				// The only change has been to an existing deferral
-				KAlarm::updateEvent(newEvent, mListView, true, false);   // keep the same event ID
-			}
-			else
-			{
-				if (KAlarm::modifyEvent(event, newEvent, mListView) == KAlarm::UPDATE_KORG_ERR)
-					KAlarm::displayUpdateError(this, KAlarm::KORG_ERR_MODIFY);
-			}
-			Undo::saveEdit(event, newEvent);
-
-			KAlarm::outputAlarmWarnings(&editDlg, &newEvent);
+			// The only change has been to an existing deferral
+			KAlarm::updateEvent(newEvent, view, true, false);   // keep the same event ID
 		}
+		else
+		{
+			if (KAlarm::modifyEvent(event, newEvent, view) == KAlarm::UPDATE_KORG_ERR)
+				KAlarm::displayKOrgUpdateError(win, KAlarm::KORG_ERR_MODIFY, 1);
+		}
+		Undo::saveEdit(event, newEvent);
+
+		KAlarm::outputAlarmWarnings(&editDlg, &newEvent);
 	}
 }
 
@@ -687,7 +696,7 @@ void MainWindow::slotDelete()
 	Undo::saveDeletes(events);
 
 	if (warnKOrg)
-		KAlarm::displayUpdateError(this, KAlarm::KORG_ERR_DELETE, (warnKOrg > 1));
+		KAlarm::displayKOrgUpdateError(this, KAlarm::KORG_ERR_DELETE, warnKOrg);
 }
 
 /******************************************************************************
@@ -716,7 +725,7 @@ void MainWindow::slotReactivate()
 	Undo::saveReactivates(events);
 
 	if (warnKOrg)
-		KAlarm::displayUpdateError(this, KAlarm::KORG_ERR_ADD, (warnKOrg > 1));
+		KAlarm::displayKOrgUpdateError(this, KAlarm::KORG_ERR_ADD, warnKOrg);
 }
 
 /******************************************************************************
@@ -799,7 +808,7 @@ void MainWindow::slotBirthdays()
 					++warnKOrg;
 			}
 			if (warnKOrg)
-				KAlarm::displayUpdateError(this, KAlarm::KORG_ERR_ADD, (warnKOrg > 1));
+				KAlarm::displayKOrgUpdateError(this, KAlarm::KORG_ERR_ADD, warnKOrg);
 			KAlarm::outputAlarmWarnings(&dlg);
 		}
 	}
@@ -848,7 +857,7 @@ void MainWindow::slotToggleTrayIcon()
 */
 void MainWindow::updateTrayIconAction()
 {
-	mActionToggleTrayIcon->setEnabled(theApp()->KDEDesktop() && !theApp()->wantRunInSystemTray());
+	mActionToggleTrayIcon->setEnabled(theApp()->haveSystemTray() && !theApp()->wantRunInSystemTray());
 	mActionToggleTrayIcon->setChecked(theApp()->trayIconDisplayed());
 }
 
@@ -1130,7 +1139,8 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
 		content.setContent(mails);
 		content.parse();
 		QString body;
-		content.textContent()->decodedText(body, true, true);    // strip trailing newlines & spaces
+		if (content.textContent())
+			content.textContent()->decodedText(body, true, true);    // strip trailing newlines & spaces
 		unsigned long sernum = 0;
 		if (e->provides(KPIM::MailListDrag::format())
 		&&  KPIM::MailListDrag::decode(e, mailList)
