@@ -1,7 +1,7 @@
 /*
  *  messagewin.h  -  displays an alarm message
  *  Program:  kalarm
- *  (C) 2001 - 2005 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright (c) 2001 - 2005 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,14 +13,16 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef MESSAGEWIN_H
 #define MESSAGEWIN_H
 
+/** @file messagewin.h - displays an alarm message */
+
 #include "mainwindowbase.h"
 #include "alarmevent.h"
 
@@ -28,6 +30,7 @@ class QPushButton;
 class KPushButton;
 class QLabel;
 class QTimer;
+class KWinModule;
 class AlarmTimeWidget;
 class DeferAlarmDlg;
 class KArtsDispatcher;
@@ -51,6 +54,7 @@ class MessageWin : public MainWindowBase
 		bool                hasDefer() const       { return !!mDeferButton; }
 		bool                isValid() const        { return !mInvalid; }
 		virtual void        show();
+		virtual QSize       sizeHint() const;
 		static int          instanceCount()        { return mWindowList.count(); }
 		static MessageWin*  findEvent(const QString& eventID);
 
@@ -63,15 +67,20 @@ class MessageWin : public MainWindowBase
 		virtual void        readProperties(KConfig*);
 
 	private slots:
+		void                slotEdit();
 		void                slotDefer();
 		void                checkDeferralLimit();
 		void                displayMainWindow();
+		void                slotShowKMailMessage();
+		void                slotSpeak();
 		void                slotPlayAudio();
 		void                checkAudioPlay();
 		void                stopPlay();
+		void                slotFade();
 		void                enableButtons();
 		void                setRemainingTextDay();
 		void                setRemainingTextMinute();
+		void                setMaxSize();
 
 	private:
 		void                initView();
@@ -79,27 +88,31 @@ class MessageWin : public MainWindowBase
 		void                initAudio(bool firstTime);
 		int                 getKMixVolume();
 		void                setKMixVolume(int percent);
-		bool                runKMix();
 #endif
 		void                displayComplete();
 		void                playAudio();
 		void                setDeferralLimit(const KAEvent&);
 
-		static QPtrList<MessageWin> mWindowList;  // list of existing message windows
+		static QValueList<MessageWin*> mWindowList;  // list of existing message windows
 		// Properties needed by readProperties()
 		QString             mMessage;
 		QFont               mFont;
 		QColor              mBgColour, mFgColour;
 		DateTime            mDateTime;        // date/time displayed in the message window
+		QDateTime           mCloseTime;       // time at which window should be auto-closed
 		QString             mEventID;
 		QString             mAudioFile;
 		float               mVolume;
+		float               mFadeVolume;
+		int                 mFadeSeconds;
 		KAAlarm::Type       mAlarmType;
 		KAEvent::Action     mAction;
+		unsigned long       mKMailSerialNumber; // if email text, message's KMail serial number, else 0
 		QStringList         mErrorMsgs;
 		int                 mRestoreHeight;
 		bool                mAudioRepeat;
 		bool                mConfirmAck;
+		bool                mShowEdit;        // display the Edit button
 		bool                mNoDefer;         // don't display a Defer option
 		bool                mInvalid;         // restored window is invalid
 		// Sound file playing
@@ -108,9 +121,10 @@ class MessageWin : public MainWindowBase
 		QCString            mKMixName;        // DCOP name for KMix
 		QString             mKMixError;       // error message starting KMix
 		QTimer*             mPlayTimer;       // timer for repeating the sound file
+		QTimer*             mFadeTimer;       // timer for fading the sound volume
 		float               mOldVolume;       // volume before volume was set for sound file
 		QString             mLocalAudioFile;  // local copy of audio file
-		QTime               mAudioFileLoadStart; // time when audio file loading started
+		QTime               mAudioFileStart;  // time when audio file loading first started, or when play first started
 		int                 mAudioFileLoadSecs;  // how many seconds it took to load audio file
 		bool                mPlayedOnce;      // the sound file has started playing at least once
 		bool                mPlayed;          // the PlayObject->play() has been called
@@ -118,11 +132,14 @@ class MessageWin : public MainWindowBase
 		KAEvent             mEvent;           // the whole event, for updating the calendar file
 		QLabel*             mRemainingText;   // the remaining time (for a reminder window)
 		KPushButton*        mOkButton;
+		QPushButton*        mEditButton;
 		QPushButton*        mDeferButton;
 		QPushButton*        mSilenceButton;
 		QPushButton*        mKAlarmButton;
+		QPushButton*        mKMailButton;
 		DeferAlarmDlg*      mDeferDlg;
 		QDateTime           mDeferLimit;      // last time to which the message can currently be deferred
+		mutable KWinModule* mWinModule;
 		int                 mFlags;
 		int                 mLateCancel;
 		int                 mButtonDelay;     // delay (ms) after window is shown before buttons are enabled
@@ -130,11 +147,11 @@ class MessageWin : public MainWindowBase
 		bool                mNoPostAction;    // don't execute any post-alarm action
 		bool                mRecreating;      // window is about to be deleted and immediately recreated
 		bool                mBeep;
+		bool                mSpeak;           // the message should be spoken via kttsd
 		bool                mRescheduleEvent; // true to delete event after message has been displayed
 		bool                mShown;           // true once the window has been displayed
 		bool                mPositioning;     // true when the window is being positioned initially
-		bool                mDeferClosing;    // the Defer button is closing the dialog
-		bool                mDeferDlgShowing; // the defer dialog is being displayed
+		bool                mNoCloseConfirm;  // the Defer or Edit button is closing the dialog
 		bool                mUsingKMix;       // master volume is being set using kmix
 };
 
