@@ -238,7 +238,7 @@ void TrayWindow::tooltipAlarmText(QString& text) const
 	{
 		KCal::Event* kcalEvent = *it;
 		event.set(*kcalEvent);
-		if (!event.expired()  &&  event.action() == KAEvent::MESSAGE)
+		if (event.enabled()  &&  !event.expired()  &&  event.action() == KAEvent::MESSAGE)
 		{
 			TipItem item;
 			DateTime dateTime = event.nextDateTime(false);
