@@ -23,6 +23,7 @@
 #include <qptrlist.h>
 #include <qstring.h>
 
+#include "karmerrors.h"
 #include "karmutility.h"
 #include "mainwindow.h"
 #include "preferences.h"
@@ -35,7 +36,7 @@
 
 MainWindow::MainWindow( const QString &icsfile )
   : DCOPObject ( "KarmDCOPIface" ),
-    KMainWindow(0), 
+    KParts::MainWindow(), 
     _accel     ( new KAccel( this ) ),
     _watcher   ( new KAccelMenuWatch( _accel, this ) ),
     _totalSum  ( 0 ),
@@ -95,6 +96,22 @@ MainWindow::MainWindow( const QString &icsfile )
     kapp->dcopClient()->registerAs( "karm" );
     kapp->dcopClient()->setDefaultObject( objId() );
   }
+
+  // Set up DCOP error messages
+  m_error[ KARM_ERR_GENERIC_SAVE_FAILED ] = 
+    i18n( "Save failed, most likely because the file could not be locked." );
+  m_error[ KARM_ERR_COULD_NOT_MODIFY_RESOURCE ] = 
+    i18n( "Could not modify calendar resource." );
+  m_error[ KARM_ERR_MEMORY_EXHAUSTED ] = 
+    i18n( "Out of memory--could not create object." );
+  m_error[ KARM_ERR_UID_NOT_FOUND ] = 
+    i18n( "UID not found." );
+  m_error[ KARM_ERR_INVALID_DATE ] = 
+    i18n( "Invalidate date--format is YYYY-MM-DD." );
+  m_error[ KARM_ERR_INVALID_TIME ] = 
+    i18n( "Invalid time--format is YYYY-MM-DDTHH:MM:SS." );
+  m_error[ KARM_ERR_INVALID_DURATION ] = 
+    i18n( "Invalid task duration--must be greater than zero." );
 }
 
 void MainWindow::slotSelectionChanged()
@@ -102,8 +119,10 @@ void MainWindow::slotSelectionChanged()
   Task* item= _taskView->current_item();
   actionDelete->setEnabled(item);
   actionEdit->setEnabled(item);
-  actionStart->setEnabled(item && !item->isRunning());
+  actionStart->setEnabled(item && !item->isRunning() && !item->isComplete());
   actionStop->setEnabled(item && item->isRunning());
+  actionMarkAsComplete->setEnabled(item && !item->isComplete());
+  actionMarkAsIncomplete->setEnabled(item && item->isComplete());
 }
 
 // This is _old_ code, but shows how to enable/disable add comment menu item.
@@ -113,21 +132,22 @@ void MainWindow::slotSelectionChanged()
 //  actionAddComment->setEnabled( on );
 //}
 
-void MainWindow::save()
+bool MainWindow::save()
 {
-  kdDebug(5970) << i18n("Saving time data to disk.") << endl;
+  kdDebug(5970) << "Saving time data to disk." << endl;
   QString err=_taskView->save();  // untranslated error msg.
   if (err.isEmpty()) statusBar()->message(i18n("Successfully saved tasks and history"),1807);
   else statusBar()->message(i18n(err.ascii()),7707); // no msgbox since save is called when exiting
   saveGeometry();
+  return true;
 }
 
 void MainWindow::exportcsvHistory()
 {
-  kdDebug(5970) << i18n("Exporting History to disk.") << endl;
+  kdDebug(5970) << "Exporting History to disk." << endl;
   QString err=_taskView->exportcsvHistory();
   if (err.isEmpty()) statusBar()->message(i18n("Successfully exported History to CSV-file"),1807);
-  else KMessageBox::error(this, i18n(err.ascii()));
+  else KMessageBox::error(this, err.ascii());
   saveGeometry();
   
 }
@@ -140,7 +160,7 @@ void MainWindow::quit()
 
 MainWindow::~MainWindow()
 {
-  kdDebug(5970) << i18n("MainWindow::~MainWindows: Quitting karm.") << endl;
+  kdDebug(5970) << "MainWindow::~MainWindows: Quitting karm." << endl;
   _taskView->stopAllTimers();
   save();
   _taskView->closeStorage();
@@ -295,6 +315,13 @@ void MainWindow::makeMenus()
       SLOT( markTaskAsComplete() ),
       actionCollection(),
       "mark_as_complete");
+  actionMarkAsIncomplete = new KAction( i18n("&Mark as Incomplete"),
+      QString::fromLatin1("document"),
+      CTRL+Key_M,
+      _taskView,
+      SLOT( markTaskAsIncomplete() ),
+      actionCollection(),
+      "mark_as_incomplete");
   actionClipTotals = new KAction( i18n("&Copy Totals to Clipboard"),
       QString::fromLatin1("klipper"),
       CTRL+Key_C,
@@ -330,9 +357,10 @@ void MainWindow::makeMenus()
                             "import_korg_events");
   */
 
-  createGUI( QString::fromLatin1("karmui.rc") );
+  setXMLFile( QString::fromLatin1("karmui.rc") );
+  createGUI( 0 );
 
-  // Tool tops must be set after the createGUI.
+  // Tool tips must be set after the createGUI.
   actionKeyBindings->setToolTip( i18n("Configure key bindings") );
   actionKeyBindings->setWhatsThis( i18n("This will let you configure key"
                                         "bindings which is specific to karm") );
@@ -394,14 +422,18 @@ void MainWindow::print()
 
 void MainWindow::loadGeometry()
 {
-  KConfig &config = *kapp->config();
+  if (initialGeometrySet()) setAutoSaveSettings();
+  else
+  {
+    KConfig &config = *kapp->config();
 
-  config.setGroup( QString::fromLatin1("Main Window Geometry") );
-  int w = config.readNumEntry( QString::fromLatin1("Width"), 100 );
-  int h = config.readNumEntry( QString::fromLatin1("Height"), 100 );
-  w = QMAX( w, sizeHint().width() );
-  h = QMAX( h, sizeHint().height() );
-  resize(w, h);
+    config.setGroup( QString::fromLatin1("Main Window Geometry") );
+    int w = config.readNumEntry( QString::fromLatin1("Width"), 100 );
+    int h = config.readNumEntry( QString::fromLatin1("Height"), 100 );
+    w = QMAX( w, sizeHint().width() );
+    h = QMAX( h, sizeHint().height() );
+    resize(w, h);
+  }
 }
 
 
@@ -442,21 +474,160 @@ QString MainWindow::version() const
   return KARM_VERSION;
 }
 
-QString MainWindow::hastodo( const QString &taskname ) const
+QString MainWindow::deletetodo()
+{
+  _taskView->deleteTask();
+  return "";
+}
+
+bool MainWindow::getpromptdelete()
+{
+  return _preferences->promptDelete();
+}
+
+QString MainWindow::setpromptdelete( bool prompt )
+{
+  _preferences->setPromptDelete( prompt );
+  return "";
+}
+
+QString MainWindow::taskIdFromName( const QString &taskname ) const
 {
   QString rval = "";
 
   Task* task = _taskView->first_child();
   while ( rval.isEmpty() && task )
   {
-    rval = _hastodo( task, taskname );
+    rval = _hasTask( task, taskname );
     task = task->nextSibling();
   }
   
   return rval;
 }
 
-QString MainWindow::_hastodo( Task* task, const QString &taskname ) const
+int MainWindow::addTask( const QString& taskname ) 
+{
+  DesktopList desktopList;
+  QString uid = _taskView->addTask( taskname, 0, 0, desktopList );
+  kdDebug(5970) << "MainWindow::addTask( " << taskname << " ) returns " << uid << endl;
+  if ( uid.length() > 0 ) return 0;
+  else
+  {
+    // We can't really tell what happened, b/c the resource framework only
+    // returns a boolean.
+    return KARM_ERR_GENERIC_SAVE_FAILED;
+  }
+}
+
+QString MainWindow::setPerCentComplete( const QString& taskName, int perCent )
+{
+  int index;
+  QString err="no such task";
+  for (int i=0; i<_taskView->count(); i++)
+  {
+    if ((_taskView->item_at_index(i)->name()==taskName))
+    {
+      index=i;
+      if (err==QString::null) err="task name is abigious";
+      if (err=="no such task") err=QString::null;
+    }
+  }
+  if (err==QString::null) 
+  {
+    _taskView->item_at_index(index)->setPercentComplete( perCent, _taskView->storage() );
+  }
+  return err;
+}
+
+int MainWindow::bookTime
+( const QString& taskId, const QString& datetime, long minutes )
+{
+  int rval = 0;
+  QDate startDate;
+  QTime startTime;
+  QDateTime startDateTime;
+  Task *task, *t;
+
+  if ( minutes <= 0 ) rval = KARM_ERR_INVALID_DURATION;
+
+  // Find task
+  task = _taskView->first_child();
+  t = NULL;
+  while ( !t && task )
+  {
+    t = _hasUid( task, taskId );
+    task = task->nextSibling();
+  }
+  if ( t == NULL ) rval = KARM_ERR_UID_NOT_FOUND;
+
+  // Parse datetime
+  if ( !rval ) 
+  {
+    startDate = QDate::fromString( datetime, Qt::ISODate );
+    if ( datetime.length() > 10 )  // "YYYY-MM-DD".length() = 10
+    {
+      startTime = QTime::fromString( datetime, Qt::ISODate );
+    }
+    else startTime = QTime( 12, 0 );
+    if ( startDate.isValid() && startTime.isValid() )
+    {
+      startDateTime = QDateTime( startDate, startTime );
+    }
+    else rval = KARM_ERR_INVALID_DATE;
+
+  }
+
+  // Update task totals (session and total) and save to disk
+  if ( !rval )
+  {
+    t->changeTotalTimes( t->sessionTime() + minutes, t->totalTime() + minutes );
+    if ( ! _taskView->storage()->bookTime( t, startDateTime, minutes * 60 ) )
+    {
+      rval = KARM_ERR_GENERIC_SAVE_FAILED;
+    }
+  }
+
+  return rval;
+}
+
+// There was something really bad going on with DCOP when I used a particular
+// argument name; if I recall correctly, the argument name was errno.
+QString MainWindow::getError( int mkb ) const
+{
+  if ( mkb <= KARM_MAX_ERROR_NO ) return m_error[ mkb ];
+  else return i18n( "Invalid error number: %1" ).arg( mkb );
+}
+
+int MainWindow::totalMinutesForTaskId( const QString& taskId )
+{
+  int rval = 0;
+  Task *task, *t;
+  
+  kdDebug(5970) << "MainWindow::totalTimeForTask( " << taskId << " )" << endl;
+
+  // Find task
+  task = _taskView->first_child();
+  t = NULL;
+  while ( !t && task )
+  {
+    t = _hasUid( task, taskId );
+    task = task->nextSibling();
+  }
+  if ( t != NULL ) 
+  {
+    rval = t->totalTime();
+    kdDebug(5970) << "MainWindow::totalTimeForTask - task found: rval = " << rval << endl;
+  }
+  else 
+  {
+    kdDebug(5970) << "MainWindow::totalTimeForTask - task not found" << endl;
+    rval = KARM_ERR_UID_NOT_FOUND;
+  }
+
+  return rval;
+}
+
+QString MainWindow::_hasTask( Task* task, const QString &taskname ) const
 {
   QString rval = "";
   if ( task->name() == taskname ) 
@@ -468,17 +639,87 @@ QString MainWindow::_hastodo( Task* task, const QString &taskname ) const
     Task* nexttask = task->firstChild();
     while ( rval.isEmpty() && nexttask )
     {
-      rval = _hastodo( nexttask, taskname );
+      rval = _hasTask( nexttask, taskname );
       nexttask = nexttask->nextSibling();
     }
   }
   return rval;
 }
 
-QString MainWindow::addtodo( const QString& taskname ) 
+Task* MainWindow::_hasUid( Task* task, const QString &uid ) const
 {
-  DesktopList desktopList;
-  return _taskView->addTask( taskname, 0, 0, desktopList );
+  Task *rval = NULL;
+
+  //kdDebug(5970) << "MainWindow::_hasUid( " << task << ", " << uid << " )" << endl;
+
+  if ( task->uid() == uid ) rval = task;
+  else
+  {
+    Task* nexttask = task->firstChild();
+    while ( !rval && nexttask )
+    {
+      rval = _hasUid( nexttask, uid );
+      nexttask = nexttask->nextSibling();
+    }
+  }
+  return rval;
+}
+QString MainWindow::starttimerfor( const QString& taskname )
+{
+  int index;
+  QString err="no such task";
+  for (int i=0; i<_taskView->count(); i++)
+  {
+    if ((_taskView->item_at_index(i)->name()==taskname))
+    {
+      index=i;
+      if (err==QString::null) err="task name is abigious";
+      if (err=="no such task") err=QString::null;
+    }
+  }
+  if (err==QString::null) _taskView->startTimerFor( _taskView->item_at_index(index) );
+  return err;
 }
 
+QString MainWindow::stoptimerfor( const QString& taskname )
+{
+  int index;
+  QString err="no such task";
+  for (int i=0; i<_taskView->count(); i++)
+  {
+    if ((_taskView->item_at_index(i)->name()==taskname))
+    {
+      index=i;
+      if (err==QString::null) err="task name is abigious";
+      if (err=="no such task") err=QString::null;
+    }
+  }
+  if (err==QString::null) _taskView->stopTimerFor( _taskView->item_at_index(index) );
+  return err;
+}
+
+QString MainWindow::exportcsvfile( QString filename, QString from, QString to, int type, bool decimalMinutes, bool allTasks, QString delimiter, QString quote )
+{
+  ReportCriteria rc;
+  rc.url=filename;
+  rc.from=QDate::fromString( from );
+  if ( rc.from.isNull() ) rc.from=QDate::fromString( from, Qt::ISODate );
+  kdDebug(5970) << "rc.from " << rc.from << endl;
+  rc.to=QDate::fromString( to );
+  if ( rc.to.isNull() ) rc.to=QDate::fromString( to, Qt::ISODate );
+  kdDebug(5970) << "rc.to " << rc.to << endl;
+  rc.reportType=(ReportCriteria::REPORTTYPE) type;  // history report or totals report 
+  rc.decimalMinutes=decimalMinutes;
+  rc.allTasks=allTasks;
+  rc.delimiter=delimiter;
+  rc.quote=quote;
+  return _taskView->report( rc );
+}
+
+QString MainWindow::importplannerfile( QString fileName )
+{
+  return _taskView->importPlanner(fileName);
+}
+
+
 #include "mainwindow.moc"
