@@ -354,7 +354,7 @@ IMAP4Protocol::get (const KURL & _url)
         if (cache)
           lastone = cache->getHeader ();
 
-        if (!cmd->isComplete ())
+        if (cmd && !cmd->isComplete ())
         {
           if ((aUpper.find ("BODYSTRUCTURE") != -1)
                     || (aUpper.find ("FLAGS") != -1)
@@ -368,15 +368,15 @@ IMAP4Protocol::get (const KURL & _url)
               // write the mime header (default is here message/rfc822)
               outputLine ("--IMAPDIGEST\r\n", 14);
               cacheOutput = true;
-              if (cache->getUid () != 0)
+              if (cache && cache->getUid () != 0)
                 outputLineStr ("X-UID: " +
                                QString::number(cache->getUid ()) + "\r\n");
-              if (cache->getSize () != 0)
+              if (cache && cache->getSize () != 0)
                 outputLineStr ("X-Length: " +
                                QString::number(cache->getSize ()) + "\r\n");
-              if (!cache->getDate ().isEmpty())
+              if (cache && !cache->getDate ().isEmpty())
                 outputLineStr ("X-Date: " + cache->getDate () + "\r\n");
-              if (cache->getFlags () != 0)
+              if (cache && cache->getFlags () != 0)
                 outputLineStr ("X-Flags: " +
                                QString::number(cache->getFlags ()) + "\r\n");
             } else cacheOutput = true;
@@ -387,7 +387,7 @@ IMAP4Protocol::get (const KURL & _url)
           }
         } // if not complete
       }
-      while (!cmd->isComplete ());
+      while (cmd && !cmd->isComplete ());
       if (aEnum == ITYPE_BOX || aEnum == ITYPE_DIR_AND_BOX)
       {
         // write the end boundary
@@ -1988,6 +1988,17 @@ bool IMAP4Protocol::makeLogin ()
     if (cmd->result () == "OK")
     {
       QValueListIterator < imapList > it = listResponses.begin();
+      if ( it == listResponses.end() )
+      {
+          // empty answer - this is a buggy imap server
+          // as a fallback we fire a normal listing and take the first answer
+          completeQueue.removeRef (cmd);
+          cmd = doCommand( imapCommand::clientList("", "%") );
+          if (cmd->result () == "OK")
+          {
+              it = listResponses.begin();
+          }
+      }
       if ( it != listResponses.end() )
       {
         namespaceToDelimiter[QString::null] = (*it).hierarchyDelimiter();
@@ -2232,6 +2243,10 @@ IMAP4Protocol::doListEntry (const KURL & _url, const QString & myBox,
           path += item.hierarchyDelimiter();
         }
         path += mailboxName;
+        if (path.upper() == "/INBOX/") {
+            // make sure the client can rely on INBOX
+            path = path.upper();
+        }
       }
       aURL.setPath(path);
       atom.m_str = aURL.url(0, 106); // utf-8
