@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  *  In addition, as a special exception, the copyright holders give
  *  permission to link the code of this program with any edition of
@@ -39,6 +39,7 @@
 #include "kmmsgpart.h"
 #include "progressmanager.h"
 using KPIM::ProgressManager;
+#include "util.h"
 
 #include <qstylesheet.h>
 #include <kio/scheduler.h>
@@ -96,11 +97,12 @@ void ImapJob::init( JobType jt, QString sets, KMFolderImap* folder,
   // imap folder, use its account for keeping track of the job. Otherwise,
   // this is a get job and the src folder is an imap one. Use its account
   // then.
-  KMAcctImap *account;
+  KMAcctImap *account = 0;
   if (folder) {
     account = folder->account();
   } else {
-    account = static_cast<KMFolderImap*>(msg_parent->storage())->account();
+    if ( msg_parent && msg_parent->storage() )
+      account = static_cast<KMFolderImap*>(msg_parent->storage())->account();
   }
   if ( !account ||
        account->makeConnection() == ImapAccountBase::Error ) {
@@ -126,7 +128,7 @@ void ImapJob::init( JobType jt, QString sets, KMFolderImap* folder,
       url.setPath( folder->imapPath() + ";SECTION=" + flags );
       ImapAccountBase::jobData jd;
       jd.parent = 0; jd.offset = 0; jd.done = 0;
-      jd.total = ( curMsg->msgSizeServer() > 0 ) ? 
+      jd.total = ( curMsg->msgSizeServer() > 0 ) ?
         curMsg->msgSizeServer() : curMsg->msgSize();
       jd.msgList.append( curMsg );
       QCString cstr( curMsg->asString() );
@@ -151,7 +153,7 @@ void ImapJob::init( JobType jt, QString sets, KMFolderImap* folder,
           mParentProgressItem,
           "ImapJobUploading"+ProgressManager::getUniqueID(),
           i18n("Uploading message data"),
-          curMsg->subject(),
+          QStyleSheet::escape( curMsg->subject() ),
           true,
           account->useSSL() || account->useTLS() );
       jd.progressItem->setTotalItems( jd.total );
@@ -190,8 +192,9 @@ void ImapJob::init( JobType jt, QString sets, KMFolderImap* folder,
                           mParentProgressItem,
                           "ImapJobCopyMove"+ProgressManager::getUniqueID(),
                           i18n("Server operation"),
-                          i18n("Source folder: ") + msg_parent->prettyURL()
-                          + " - destination folder: " + mDestFolder->prettyURL(),
+                          i18n("Source folder: %1 - Destination folder: %2")
+                            .arg( QStyleSheet::escape( msg_parent->prettyURL() ),
+                                  QStyleSheet::escape( mDestFolder->prettyURL() ) ),
                           true,
                           account->useSSL() || account->useTLS() );
     jd.progressItem->setTotalItems( jd.total );
@@ -221,29 +224,8 @@ ImapJob::~ImapJob()
   if ( mDestFolder )
   {
     KMAcctImap *account = static_cast<KMFolderImap*>(mDestFolder->storage())->account();
-    if ( account &&  mJob ) {
-      ImapAccountBase::JobIterator it = account->findJob( mJob );
-      if ( it != account->jobsEnd() ) {
-        if( (*it).progressItem ) {
-          (*it).progressItem->setComplete();
-          (*it).progressItem = 0;
-        }
-        if ( !(*it).msgList.isEmpty() ) {
-          for ( QPtrListIterator<KMMessage> mit( (*it).msgList ); mit.current(); ++mit )
-            mit.current()->setTransferInProgress( false );
-        }
-      }
-      account->removeJob( mJob );
-    }
-    account->mJobList.remove( this );
-    mDestFolder->close();
-  }
-
-  if ( mSrcFolder ) {
-    if (!mDestFolder || mDestFolder != mSrcFolder) {
-      if (! (mSrcFolder->folderType() == KMFolderTypeImap) ) return;
-      KMAcctImap *account = static_cast<KMFolderImap*>(mSrcFolder->storage())->account();
-      if ( account && mJob ) {
+    if ( account ) {
+      if ( mJob ) {
         ImapAccountBase::JobIterator it = account->findJob( mJob );
         if ( it != account->jobsEnd() ) {
           if( (*it).progressItem ) {
@@ -255,9 +237,34 @@ ImapJob::~ImapJob()
               mit.current()->setTransferInProgress( false );
           }
         }
-        account->removeJob( mJob ); // remove the associated kio job
+        account->removeJob( mJob );
+      }
+      account->mJobList.remove( this );
+    }
+    mDestFolder->close();
+  }
+
+  if ( mSrcFolder ) {
+    if (!mDestFolder || mDestFolder != mSrcFolder) {
+      if (! (mSrcFolder->folderType() == KMFolderTypeImap) ) return;
+      KMAcctImap *account = static_cast<KMFolderImap*>(mSrcFolder->storage())->account();
+      if ( account ) {
+        if ( mJob ) {
+          ImapAccountBase::JobIterator it = account->findJob( mJob );
+          if ( it != account->jobsEnd() ) {
+            if( (*it).progressItem ) {
+              (*it).progressItem->setComplete();
+              (*it).progressItem = 0;
+            }
+            if ( !(*it).msgList.isEmpty() ) {
+              for ( QPtrListIterator<KMMessage> mit( (*it).msgList ); mit.current(); ++mit )
+                mit.current()->setTransferInProgress( false );
+            }
+          }
+          account->removeJob( mJob ); // remove the associated kio job
+        }
+        account->mJobList.remove( this ); // remove the folderjob
       }
-      account->mJobList.remove( this ); // remove the folderjob
     }
     mSrcFolder->close();
   }
@@ -268,15 +275,15 @@ ImapJob::~ImapJob()
 void ImapJob::slotGetNextMessage()
 {
   KMMessage *msg = mMsgList.first();
-  KMFolderImap *msgParent = static_cast<KMFolderImap*>(msg->storage());
-  KMAcctImap *account = msgParent->account();
-  if ( msg->UID() == 0 )
+  KMFolderImap *msgParent = msg ? static_cast<KMFolderImap*>(msg->storage()) : 0;
+  if ( !msgParent || msg->UID() == 0 )
   {
-    emit messageRetrieved( msg );
-    account->mJobList.remove( this );
+    // broken message
+    emit messageRetrieved( 0 );
     deleteLater();
     return;
   }
+  KMAcctImap *account = msgParent->account();
   KURL url = account->getUrl();
   QString path = msgParent->imapPath() + ";UID=" + QString::number(msg->UID());
   ImapAccountBase::jobData jd;
@@ -304,12 +311,12 @@ void ImapJob::slotGetNextMessage()
 //  kdDebug(5006) << "ImapJob::slotGetNextMessage - retrieve " << url.path() << endl;
   // protect the message, otherwise we'll get crashes afterwards
   msg->setTransferInProgress( true );
-  const QString escapedSubject = QStyleSheet::escape( msg->subject() );
   jd.progressItem = ProgressManager::createProgressItem(
                           mParentProgressItem,
                           "ImapJobDownloading"+ProgressManager::getUniqueID(),
                           i18n("Downloading message data"),
-                          i18n("Message with subject: ") + escapedSubject,
+                          i18n("Message with subject: ") +
+                          QStyleSheet::escape( msg->subject() ),
                           true,
                           account->useSSL() || account->useTLS() );
   connect ( jd.progressItem, SIGNAL( progressItemCanceled( KPIM::ProgressItem*)),
@@ -343,6 +350,7 @@ void ImapJob::slotGetMessageResult( KIO::Job * job )
 {
   KMMessage *msg = mMsgList.first();
   if (!msg || !msg->parent() || !job) {
+    emit messageRetrieved( 0 );
     deleteLater();
     return;
   }
@@ -351,6 +359,7 @@ void ImapJob::slotGetMessageResult( KIO::Job * job )
     msg->setTransferInProgress( false );
   KMAcctImap *account = parent->account();
   if ( !account ) {
+    emit messageRetrieved( 0 );
     deleteLater();
     return;
   }
@@ -384,19 +393,26 @@ void ImapJob::slotGetMessageResult( KIO::Job * job )
 
         // Convert CR/LF to LF.
         size_t dataSize = (*it).data.size();
-        dataSize = FolderStorage::crlf2lf( (*it).data.data(), dataSize ); // always <=
+        dataSize = Util::crlf2lf( (*it).data.data(), dataSize ); // always <=
         (*it).data.resize( dataSize );
 
+        // During the construction of the message from the byteArray it does
+        // not have a uid. Therefore we have to make sure that no connected
+        // slots are called, since they would operate on uid == 0.
+        msg->parent()->storage()->blockSignals( true );
         msg->fromByteArray( (*it).data );
-        // reconstruct as it may be overwritten above
-        msg->setUID(uid);
-        if ( size > 0 && msg->msgSizeServer() == 0 )
+        // now let others react
+        msg->parent()->storage()->blockSignals( false );
+        if ( size > 0 && msg->msgSizeServer() == 0 ) {
           msg->setMsgSizeServer(size);
+        }
+        // reconstruct the UID as it gets overwritten above
+        msg->setUID(uid);
 
       } else {
         // Convert CR/LF to LF.
         size_t dataSize = (*it).data.size();
-        dataSize = FolderStorage::crlf2lf( (*it).data.data(), dataSize ); // always <=
+        dataSize = Util::crlf2lf( (*it).data.data(), dataSize ); // always <=
         (*it).data.resize( dataSize );
 
         // Update the body of the retrieved part (the message notifies all observers)
@@ -434,7 +450,7 @@ void ImapJob::slotGetMessageResult( KIO::Job * job )
       parent->ignoreJobsForMessage( msg );
       int idx = parent->find( msg );
       if (idx != -1) parent->removeMsg( idx, true );
-      // the removeMsg will unGet the message, which will delete all 
+      // the removeMsg will unGet the message, which will delete all
       // jobs, including this one
       return;
     }
@@ -560,28 +576,15 @@ void ImapJob::slotCopyMessageInfoData(KIO::Job * job, const QString & data)
     QValueList<ulong> newuids = KMFolderImap::splitSets(newUid);
 
     int index = -1;
-    if ( !(*it).msgList.isEmpty() )
+    KMMessage * msg;
+    for ( msg = (*it).msgList.first(); msg; msg = (*it).msgList.next() )
     {
-      KMMessage * msg;
-      for ( msg = (*it).msgList.first(); msg; msg = (*it).msgList.next() )
-      {
-        ulong uid = msg->UID();
-        index = olduids.findIndex(uid);
-        if (index > -1)
-        {
-          // found, get the new uid
-          const ulong * sernum = (ulong *)msg->getMsgSerNum();
-          imapFolder->insertUidSerNumEntry(newuids[index], sernum);
-        }
-      }
-    } else if (mMsgList.first()) {
-      ulong uid = mMsgList.first()->UID();
+      ulong uid = msg->UID();
       index = olduids.findIndex(uid);
       if (index > -1)
       {
         // found, get the new uid
-        const ulong * sernum = (ulong *)mMsgList.first()->getMsgSerNum();
-        imapFolder->insertUidSerNumEntry(newuids[index], sernum);
+        imapFolder->saveMsgMetaData( msg, newuids[index] );
       }
     }
   }
@@ -598,12 +601,9 @@ void ImapJob::slotPutMessageInfoData(KIO::Job *job, const QString &data)
   if ( data.find("UID") != -1 )
   {
     ulong uid = ( data.right(data.length()-4) ).toInt();
-
     if ( !(*it).msgList.isEmpty() )
     {
-      const ulong * sernum = (ulong *)(*it).msgList.first()->getMsgSerNum();
-      if ( sernum )
-        imapFolder->insertUidSerNumEntry( uid, sernum );
+      imapFolder->saveMsgMetaData( (*it).msgList.first(), uid );
     }
   }
 }
