@@ -49,6 +49,9 @@ using KPIM::ProgressManager;
 #include <kio/slave.h>
 #include <kmessagebox.h>
 #include <kdebug.h>
+
+#include <qstylesheet.h>
+
 #include <errno.h>
 
 //-----------------------------------------------------------------------------
@@ -284,7 +287,8 @@ void KMAcctImap::processNewMail(bool interactive)
   mMailCheckProgressItem =
     ProgressManager::createProgressItem(
         "MailCheckAccount" + name(),
-        i18n("Checking account: " ) + name(),
+        // FIXME Replace by i18n("Checking account: %1" ).arg( ... )
+        i18n("Checking account: " ) + QStyleSheet::escape( name() ),
         QString::null, // status
         true, // can be canceled
         useSSL() || useTLS() );
