@@ -1724,7 +1724,7 @@ KMCommand::Result KMCopyCommand::execute()
       msg = srcFolder->getMsg(idx);
     }
 
-    if (srcFolder &&
+    if (srcFolder && mDestFolder &&
         (srcFolder->folderType()== KMFolderTypeImap) &&
         (mDestFolder->folderType() == KMFolderTypeImap) &&
         (static_cast<KMFolderImap*>(srcFolder->storage())->account() ==
@@ -1761,7 +1761,7 @@ KMCommand::Result KMCopyCommand::execute()
       }
     }
 
-    if (!isMessage && list.isEmpty())
+    if (srcFolder && !isMessage && list.isEmpty())
     {
       assert(idx != -1);
       srcFolder->unGetMsg( idx );
