@@ -57,6 +57,7 @@ using KMail::RenameJob;
 
 #include <qbuffer.h>
 #include <qtextcodec.h>
+#include <qstylesheet.h>
 
 #include <assert.h>
 
@@ -110,6 +111,11 @@ void KMFolderImap::close(bool aForced)
   if (mOpenCount <= 0 ) return;
   if (mOpenCount > 0) mOpenCount--;
   if (mOpenCount > 0 && !aForced) return;
+  if (isSelected() && !aForced) {
+      kdWarning(5006) << "Trying to close the selected folder " << label() << 
+          " - ignoring!" << endl;
+      return;
+  }
   // FIXME is this still needed?
   if (mAccount)
     mAccount->ignoreJobsForFolder( folder() );
@@ -222,8 +228,10 @@ void KMFolderImap::remove()
   ImapAccountBase::jobData jd(url.url());
   jd.progressItem = ProgressManager::createProgressItem(
                       "ImapFolderRemove" + ProgressManager::getUniqueID(),
+                      // FIXME Replace by i18n("Removing folder")
                       "Removing folder",
-                      "URL: " + folder()->prettyURL(),
+                      // FIXME Replace by i18n( "URL: %1" ).arg( ... )
+                      "URL: " + QStyleSheet::escape( folder()->prettyURL() ),
                       false,
                       mAccount->useSSL() || mAccount->useTLS() );
   mAccount->insertJob(job, jd);
@@ -466,7 +474,8 @@ int KMFolderImap::addMsg(QPtrList<KMMessage>& msgList, QValueList<int>& aIndex_r
       mAddMessageProgressItem = ProgressManager::createProgressItem(
           "Uploading"+ProgressManager::getUniqueID(),
           i18n("Uploading message data"),
-          i18n("Destination folder: ") + folder()->prettyURL(),
+          // FIXME Replace by i18n("Destination folder: %1").arg( ... )
+          i18n("Destination folder: ") + QStyleSheet::escape( folder()->prettyURL() ),
           true,
           mAccount->useSSL() || mAccount->useTLS() );
       mAddMessageProgressItem->setTotalItems( msgList.count() );
@@ -873,8 +882,10 @@ void KMFolderImap::initInbox()
     }
     kmkernel->imapFolderMgr()->contentsChanged();
   }
-  f->initializeFrom( this, "/INBOX/", "message/directory" );
-  f->setChildrenState( QString::null );
+  if ( f ) {
+    f->initializeFrom( this, "/INBOX/", "message/directory" );
+    f->setChildrenState( QString::null );
+  }
   // so we have an INBOX
   mAccount->setHasInbox( true );
 }
@@ -1026,7 +1037,7 @@ void KMFolderImap::checkValidity()
     mMailCheckProgressItem = ProgressManager::createProgressItem(
               parent,
               "MailCheck" + folder()->prettyURL(),
-              folder()->prettyURL(),
+              QStyleSheet::escape( folder()->prettyURL() ),
               i18n("checking"),
               false,
               account()->useSSL() || account()->useTLS() );
@@ -1086,17 +1097,20 @@ void KMFolderImap::slotCheckValidityResult(KIO::Job * job)
     int a = cstr.find("X-uidValidity: ");
     int b = cstr.find("\r\n", a);
     QString uidv;
-    if ( (b - a - 15) >= 0 ) uidv = cstr.mid(a + 15, b - a - 15);
+    if ( (b - a - 15) >= 0 ) 
+        uidv = cstr.mid(a + 15, b - a - 15);
     a = cstr.find("X-Access: ");
     b = cstr.find("\r\n", a);
     QString access;
-    if ( (b - a - 10) >= 0 ) access = cstr.mid(a + 10, b - a - 10);
+    if ( (b - a - 10) >= 0 ) 
+        access = cstr.mid(a + 10, b - a - 10);
     mReadOnly = access == "Read only";
     a = cstr.find("X-Count: ");
     b = cstr.find("\r\n", a);
     int exists = -1;
-    bool ok;
-    if ( (b - a - 9) >= 0 ) exists = cstr.mid(a + 9, b - a - 9).toInt(&ok);
+    bool ok = false;
+    if ( (b - a - 9) >= 0 ) 
+        exists = cstr.mid(a + 9, b - a - 9).toInt(&ok);
     if ( !ok ) exists = -1;
     QString startUid;
     if (uidValidity() != uidv)
@@ -1966,7 +1980,7 @@ bool KMFolderImap::processNewMail(bool)
   mMailCheckProgressItem = ProgressManager::createProgressItem(
               "MailCheckAccount" + account()->name(),
               "MailCheck" + folder()->prettyURL(),
-              folder()->prettyURL(),
+              QStyleSheet::escape( folder()->prettyURL() ),
               i18n("updating message counts"),
               false,
               account()->useSSL() || account()->useTLS() );
