@@ -205,7 +205,16 @@ unsigned long KMMsgDict::insert(unsigned long msgSerNum,
   }
 
   KMFolderIndex* folder = static_cast<KMFolderIndex*>( msg->storage() );
-  if (folder && index == -1)
+  if ( !folder ) {
+    kdDebug(5006) << "KMMsgDict::insert: Cannot insert the message, "
+      << "null pointer to storage. Requested serial: " << msgSerNum
+      << endl;
+    kdDebug(5006) << "  Message info: Subject: " << msg->subject() << ", To: "
+      << msg->toStrip() << ", Date: " << msg->dateStr() << endl; 
+    return 0;
+  }
+
+  if (index == -1)
     index = folder->find(msg);
 
   // Should not happen, indicates id file corruption
@@ -241,7 +250,16 @@ void KMMsgDict::replace(unsigned long msgSerNum,
 		       const KMMsgBase *msg, int index)
 {
   KMFolderIndex* folder = static_cast<KMFolderIndex*>( msg->storage() );
-  if ( folder && index == -1 )
+  if ( !folder ) {
+    kdDebug(5006) << "KMMsgDict::replace: Cannot replace the message serial "
+      << "number, null pointer to storage. Requested serial: " << msgSerNum
+      << endl;
+    kdDebug(5006) << "  Message info: Subject: " << msg->subject() << ", To: "
+      << msg->toStrip() << ", Date: " << msg->dateStr() << endl; 
+    return;
+  }
+
+  if ( index == -1 )
     index = folder->find( msg );
 
   remove( msgSerNum );
