@@ -9,7 +9,7 @@
     version 2.0, as published by the Free Software Foundation.
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software Foundation,
-    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, US
+    Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
 */
 
 #ifdef HAVE_CONFIG_H
@@ -20,6 +20,7 @@
 
 #include "kmtransport.h"
 #include "kmkernel.h"
+#include <kapplication.h>
 #include <kconfig.h>
 
 namespace KMail {
@@ -40,4 +41,28 @@ namespace KMail {
     return transportNames;
   }
 
+  // more or less copied from AccountManager
+  uint TransportManager::createId()
+  {
+    QValueList<unsigned int> usedIds;
+
+    KConfigGroup general( KMKernel::config(), "General");
+    int numTransports = general.readNumEntry( "transports", 0 );
+
+    for ( int i = 1 ; i <= numTransports ; i++ ) {
+      KMTransportInfo ti;
+      ti.readConfig( i );
+      usedIds << ti.id();
+    }
+
+    usedIds << 0; // 0 is default for unknown
+    int newId;
+    do
+    {
+      newId = kapp->random();
+    } while ( usedIds.find(newId) != usedIds.end() );
+
+    return newId;
+  }
+
 } // namespace KMail
