@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -60,7 +60,8 @@ KNodePart::KNodePart(QWidget *parentWidget, const char *widgetName,
   kdDebug(5003) << "KNodePart()..." << endl;
   kdDebug(5003) << "  InstanceName: " << kapp->instanceName() << endl;
 
-  KGlobal::locale()->insertCatalogue("libkdenetwork");
+  KGlobal::locale()->insertCatalogue("libkdepim");
+  KGlobal::locale()->insertCatalogue("libkpgp");
   kapp->dcopClient()->suspend(); // Don't handle DCOP requests yet
   KGlobal::iconLoader()->addAppDir("knode");
   knGlobals.instance = KNodeFactory::instance();
