@@ -1,6 +1,7 @@
 /*
     This file is part of Kontact.
-    Copyright (c) 2003 Kontact Developer
+
+    Copyright (c) 2001 Matthias Hoelzer-Kluepfel <mhk@kde.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -14,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -42,7 +43,6 @@
 #include <libkdepim/maillistdrag.h>
 
 #include "core.h"
-#include "kabsummarywidget.h"
 #include "plugin.h"
 
 #include "kaddressbook_plugin.h"
@@ -58,7 +58,7 @@ KAddressbookPlugin::KAddressbookPlugin( Kontact::Core *core, const char *, const
   setInstance( KAddressbookPluginFactory::instance() );
 
   insertNewAction( new KAction( i18n( "New Contact..." ), "identity",
-			             0, this, SLOT( slotNewContact() ), actionCollection(),
+			             CTRL+SHIFT+Key_C, this, SLOT( slotNewContact() ), actionCollection(),
                    "new_contact" ) );
   mUniqueAppWatcher = new Kontact::UniqueAppWatcher(
       new Kontact::UniqueAppHandlerFactory<KABUniqueAppHandler>(), this );
@@ -102,10 +102,7 @@ KAddressBookIface_stub *KAddressbookPlugin::interface()
 
 void KAddressbookPlugin::slotNewContact()
 {
-  (void) part(); // ensure part is loaded
-  Q_ASSERT( mStub );
-  if ( mStub )
-    mStub->newContact();
+  interface()->newContact();
 }
 
 bool KAddressbookPlugin::createDCOPInterface( const QString& serviceType )
@@ -155,15 +152,10 @@ void KAddressbookPlugin::processDropEvent( QDropEvent *event )
     return;
   }
 
-  KMessageBox::sorry( core(), i18n("Cannot handle drop events of type '%1'.")
+  KMessageBox::sorry( core(), i18n( "Cannot handle drop events of type '%1'." )
                       .arg( event->format() ) );
 }
 
-Kontact::Summary *KAddressbookPlugin::createSummaryWidget( QWidget *parentWidget )
-{
-  return new KABSummaryWidget( this, parentWidget );
-}
-
 ////
 
 #include "../../../kaddressbook/kaddressbook_options.h"
