@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -78,6 +78,7 @@ TimeLabels::TimeLabels(int rows,QWidget *parent,const char *name,WFlags f) :
   QScrollView(parent,name,f)
 {
   mRows = rows;
+  mMiniWidth = 0;
 
   mCellHeight = KOPrefs::instance()->mHourSize*4;
 
@@ -86,7 +87,7 @@ TimeLabels::TimeLabels(int rows,QWidget *parent,const char *name,WFlags f) :
   setHScrollBarMode(AlwaysOff);
   setVScrollBarMode(AlwaysOff);
 
-  resizeContents(50,mRows * mCellHeight);
+  resizeContents(50, int(mRows * mCellHeight) );
 
   viewport()->setBackgroundMode( PaletteBackground );
 
@@ -113,7 +114,7 @@ void TimeLabels::hideMousePos()
   mMousePos->hide();
 }
 
-void TimeLabels::setCellHeight(int height)
+void TimeLabels::setCellHeight(double height)
 {
   mCellHeight = height;
 }
@@ -124,52 +125,76 @@ void TimeLabels::setCellHeight(int height)
 */
 void TimeLabels::drawContents(QPainter *p,int cx, int cy, int cw, int ch)
 {
-  // bug:  the parameters cx, cy, cw, ch are the areas that need to be
+  // bug:  the parameters cx and cw are the areas that need to be
   //       redrawn, not the area of the widget.  unfortunately, this
   //       code assumes the latter...
 
   // now, for a workaround...
-  // these two assignments fix the weird redraw bug
-  cx = contentsX() + 2;
-  cw = contentsWidth() - 2;
-  int visWidth = visibleWidth();
-  double cellHeight=mCellHeight;
-  if (mAgenda) cellHeight=(4*mAgenda->gridSpacingY());
+  cx = contentsX() + frameWidth()*2;
+  cw = contentsWidth() ;
   // end of workaround
 
-  int cell = ((int)(cy/cellHeight));
-  double y = (cell * cellHeight);
+  int cell = ((int)(cy/mCellHeight));
+  double y = cell * mCellHeight;
   QFontMetrics fm = fontMetrics();
   QString hour;
-  QString suffix;
-  QString fullTime;
+  QString suffix = "am";
+  int timeHeight =  fm.ascent();
+  QFont nFont = font();
+  p->setFont( font() );
 
-  while (y < cy + ch) {
-    p->drawLine(cx,(int)y,cx+cw,(int)y);
-    hour.setNum(cell);
-    suffix = "am";
-
-    // handle 24h and am/pm time formats
-    // FIXME: don't construct this manually, might break translation!
-    if (KGlobal::locale()->use12Clock()) {
+  if (!KGlobal::locale()->use12Clock()) {
+      suffix = "00";
+  } else
       if (cell > 11) suffix = "pm";
+
+  if ( timeHeight >  mCellHeight ) {
+    timeHeight = int(mCellHeight-1);
+    int pointS = nFont.pointSize();
+    while ( pointS > 4 ) {
+      nFont.setPointSize( pointS );
+      fm = QFontMetrics( nFont );
+      if ( fm.ascent() < mCellHeight )
+        break;
+      -- pointS;
+    }
+    fm = QFontMetrics( nFont );
+    timeHeight = fm.ascent();
+  }
+  //timeHeight -= (timeHeight/4-2);
+  QFont sFont = nFont;
+  sFont.setPointSize( sFont.pointSize()/2 );
+  QFontMetrics fmS(  sFont );
+  int startW = mMiniWidth - frameWidth()-2 ;
+  int tw2 = fmS.width(suffix);
+  int divTimeHeight = (timeHeight-1) /2 - 1;
+  //testline
+  //p->drawLine(0,0,0,contentsHeight());
+  while (y < cy + ch+mCellHeight) {
+    // hour, full line
+    p->drawLine( cx, int(y), cw+2, int(y) );
+    hour.setNum(cell);
+    // handle 24h and am/pm time formats
+    if (KGlobal::locale()->use12Clock()) {
+      if (cell == 12) suffix = "pm";
       if (cell == 0) hour.setNum(12);
       if (cell > 12) hour.setNum(cell - 12);
-    } else {
-      suffix = ":00";
     }
 
-    // create string in format of "XX:XX" or "XXpm/am"
-    fullTime = hour + suffix;
-
     // center and draw the time label
-    QRect r( cx, (int)y+3, visWidth-4, (int)(y+cellHeight-3) );
-    p->drawText ( r, Qt::AlignHCenter | Qt::AlignTop | Qt::SingleLine, fullTime );
+    int timeWidth = fm.width(hour);
+    int offset = startW - timeWidth - tw2 -1 ;
+    p->setFont( nFont );
+    p->drawText( offset, int(y+timeHeight), hour);
+    p->setFont( sFont );
+    offset = startW - tw2;
+    p->drawText( offset, int(y+timeHeight-divTimeHeight), suffix);
 
     // increment indices
-    y += cellHeight;
+    y += mCellHeight;
     cell++;
   }
+
 }
 
 /**
@@ -177,33 +202,38 @@ void TimeLabels::drawContents(QPainter *p,int cx, int cy, int cw, int ch)
 */
 int TimeLabels::minimumWidth() const
 {
-  QFontMetrics fm = fontMetrics();
-
-  int borderWidth = 4;
-
-  // the minimum width possible
-  int width = fm.width("88:88") + 2*borderWidth;
-
-  return width;
+  return mMiniWidth;
 }
 
 /** updates widget's internal state */
 void TimeLabels::updateConfig()
 {
-  // set the font
-//  config->setGroup("Fonts");
-//  QFont font = config->readFontEntry("TimeBar Font");
   setFont(KOPrefs::instance()->mTimeBarFont);
 
+  QString test = "20";
+  if ( KGlobal::locale()->use12Clock() )
+      test = "12";
+  mMiniWidth = fontMetrics().width( test );
+  if ( KGlobal::locale()->use12Clock() )
+      test = "pm";
+  else {
+      test = "00";
+  }
+  QFont sFont = font();
+  sFont.setPointSize(  sFont.pointSize()/2 );
+  QFontMetrics fmS(   sFont );
+  mMiniWidth += fmS.width(  test ) + frameWidth()*2+4 ;
   // update geometry restrictions based on new settings
-  setFixedWidth(minimumWidth());
+  setFixedWidth(  mMiniWidth );
 
   // update HourSize
   mCellHeight = KOPrefs::instance()->mHourSize*4;
-  if (mCellHeight>mAgenda->gridSpacingY())
-    mCellHeight=(int)(4*mAgenda->gridSpacingY());
-        // FIXME: Why the heck do we set the width to 50???
-  resizeContents(50,mRows * mCellHeight);
+  // If the agenda is zoomed out so that more then 24 would be shown,
+  // the agenda only shows 24 hours, so we need to take the cell height
+  // from the agenda, which is larger than the configured one!
+  if ( mCellHeight < 4*mAgenda->gridSpacingY() )
+       mCellHeight = 4*mAgenda->gridSpacingY();
+  resizeContents( mMiniWidth, int(mRows * mCellHeight+1) );
 }
 
 /** update time label positions */
@@ -221,6 +251,7 @@ void TimeLabels::setAgenda(KOAgenda* agenda)
   connect(mAgenda, SIGNAL(mousePosSignal(const QPoint &)), this, SLOT(mousePosChanged(const QPoint &)));
   connect(mAgenda, SIGNAL(enterAgenda()), this, SLOT(showMousePos()));
   connect(mAgenda, SIGNAL(leaveAgenda()), this, SLOT(hideMousePos()));
+  connect(mAgenda, SIGNAL(gridSpacingYChanged( double ) ), this, SLOT( setCellHeight( double ) ) );
 }
 
 
@@ -444,7 +475,7 @@ KOAgendaView::KOAgendaView(Calendar *cal,QWidget *parent,const char *name) :
     connect( mExpandButton, SIGNAL( clicked() ), SIGNAL( toggleExpand() ) );
   } else {
     QLabel *label = new QLabel( i18n("All Day"), mDummyAllDayLeft );
-    label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
+    label->setAlignment( Qt::AlignRight | Qt::AlignVCenter | Qt::WordBreak );
   }
 
   mAllDayAgenda = new KOAgenda(1,mAllDayFrame);
@@ -831,8 +862,20 @@ bool KOAgendaView::eventDurationHint( QDateTime &startDt, QDateTime &endDt,
                                       bool &allDay )
 {
   if ( selectionStart().isValid() ) {
-    startDt = selectionStart();
-    endDt = selectionEnd();
+    QDateTime start = selectionStart();
+    QDateTime end = selectionEnd();
+
+    if ( start.secsTo( end ) == 15*60 ) {
+      // One cell in the agenda view selected, e.g.
+      // because of a double-click, => Use the default duration
+      QTime defaultDuration( KOPrefs::instance()->mDefaultDuration.time() );
+      int addSecs = ( defaultDuration.hour()*3600 ) +
+                    ( defaultDuration.minute()*60 );
+      end = start.addSecs( addSecs );
+    }
+
+    startDt = start;
+    endDt = end;
     allDay = selectedIsAllDay();
     return true;
   }
@@ -974,9 +1017,11 @@ void KOAgendaView::updateEventDates( KOAgendaItem *item )
   }
   // FIXME: Adjusting the recurrence should really go to CalendarView so this
   // functionality will also be available in other views!
+  // TODO_Recurrence: This does not belong here, and I'm not really sure
+  // how it's supposed to work anyway.
   Recurrence *recur = incidence->recurrence();
-  if ( recur->doesRecur() && daysOffset != 0 ) {
-    switch ( recur->doesRecur() ) {
+/*  if ( recur->doesRecur() && daysOffset != 0 ) {
+    switch ( recur->recurrenceType() ) {
       case Recurrence::rYearlyPos: {
         int freq = recur->frequency();
         int duration = recur->duration();
@@ -1107,13 +1152,13 @@ void KOAgendaView::updateEventDates( KOAgendaItem *item )
     if ( recur->duration()==0 ) { // end by date
       recur->setEndDate( recur->endDate().addDays( daysOffset ) );
     }
-    KMessageBox::information( this, i18n("A recurring incidence was moved "
+    KMessageBox::information( this, i18n("A recurring calendar item was moved "
                               "to a different day. The recurrence settings "
                               "have been updated with that move. Please check "
-                              "them in the incidence editor."),
+                              "them in the editor."),
                               i18n("Recurrence Moved"),
                               "RecurrenceMoveInAgendaWarning" );
-  }
+  }*/
 
   // FIXME: use a visitor here
   if ( incidence->type() == "Event" ) {
@@ -1199,8 +1244,9 @@ void KOAgendaView::insertIncidence( Incidence *incidence, const QDate &curDate,
   int endX;
   if ( event ) {
     beginX = curDate.daysTo( incidence->dtStart().date() ) + curCol;
-    endX = curDate.daysTo( event->dtEnd().date() ) + curCol;
+    endX = curDate.daysTo( event->dateEnd() ) + curCol;
   } else if ( todo ) {
+    if ( ! todo->hasDueDate() ) return;  // todo shall not be displayed if it has no date
     beginX = curDate.daysTo( todo->dtDue().date() ) + curCol;
     endX = beginX;
   } else {
@@ -1210,6 +1256,7 @@ void KOAgendaView::insertIncidence( Incidence *incidence, const QDate &curDate,
   if ( todo && todo->isOverdue() ) {
     mAllDayAgenda->insertAllDayItem( incidence, curDate, curCol, curCol );
   } else if ( incidence->doesFloat() ) {
+// FIXME: This breaks with recurring multi-day events!
     if ( incidence->recurrence()->doesRecur() ) {
       mAllDayAgenda->insertAllDayItem( incidence, curDate, curCol, curCol );
     } else {
@@ -1221,7 +1268,9 @@ void KOAgendaView::insertIncidence( Incidence *incidence, const QDate &curDate,
     }
   } else if ( event && event->isMultiDay() ) {
     int startY = mAgenda->timeToY( event->dtStart().time() );
-    int endY = mAgenda->timeToY( event->dtEnd().time() ) - 1;
+    QTime endtime( event->dtEnd().time() );
+    if ( endtime == QTime( 0, 0, 0 ) ) endtime = QTime( 23, 59, 59 );
+    int endY = mAgenda->timeToY( endtime ) - 1;
     if ( (beginX <= 0 && curCol == 0) || beginX == curCol ) {
       mAgenda->insertMultiItem( event, curDate, beginX, endX, startY, endY );
     }
@@ -1239,7 +1288,9 @@ void KOAgendaView::insertIncidence( Incidence *incidence, const QDate &curDate,
     int startY = 0, endY = 0;
     if ( event ) {
       startY = mAgenda->timeToY( incidence->dtStart().time() );
-      endY = mAgenda->timeToY( event->dtEnd().time() ) - 1;
+      QTime endtime( event->dtEnd().time() );
+      if ( endtime == QTime( 0, 0, 0 ) ) endtime = QTime( 23, 59, 59 );
+      endY = mAgenda->timeToY( endtime ) - 1;
     }
     if ( todo ) {
       QTime t = todo->dtDue().time();
@@ -1270,6 +1321,7 @@ void KOAgendaView::changeIncidenceDisplayAdded( Incidence *incidence )
     QDate curDate;
     for( dit = mSelectedDates.begin(); dit != mSelectedDates.end(); ++dit ) {
       curDate = *dit;
+// FIXME: This breaks with recurring multi-day events!
       if ( incidence->recursOn( curDate ) ) {
         insertIncidence( incidence, curDate );
       }
@@ -1279,7 +1331,7 @@ void KOAgendaView::changeIncidenceDisplayAdded( Incidence *incidence )
 
   QDate endDt;
   if ( incidence->type() == "Event" )
-    endDt = (static_cast<Event *>(incidence))->dtEnd().date();
+    endDt = (static_cast<Event *>(incidence))->dateEnd();
   if ( todo ) {
     endDt = todo->isOverdue() ? QDate::currentDate()
                               : todo->dtDue().date();
@@ -1303,7 +1355,8 @@ void KOAgendaView::changeIncidenceDisplay( Incidence *incidence, int mode )
         // recreating everything even causes troubles: dropping to the day matrix
         // recreates the agenda items, but the evaluation is still in an agendaItems' code,
         // which was deleted in the mean time. Thus KOrg crashes...
-      changeIncidenceDisplayAdded( incidence );
+      if ( mAllowAgendaUpdate )
+        changeIncidenceDisplayAdded( incidence );
       break;
     }
     case KOGlobals::INCIDENCEEDITED: {
@@ -1371,7 +1424,9 @@ void KOAgendaView::fillAgenda()
 //    kdDebug(5850) << "KOAgendaView::fillAgenda(): " << currentDate.toString()
 //              << endl;
 
-    dayEvents = calendar()->events(currentDate,true);
+    dayEvents = calendar()->events(currentDate,
+                                   EventSortStartDate,
+                                   SortDirectionAscending);
 
     // Default values, which can never be reached
     mMinY[curCol] = mAgenda->timeToY(QTime(23,59)) + 1;
@@ -1499,7 +1554,7 @@ void KOAgendaView::slotTodoDropped( Todo *todo, const QPoint &gpos, bool allDay
         mChanger->changeIncidence( oldTodo, existingTodo );
         mChanger->endChange( existingTodo );
       } else {
-        KMessageBox::sorry( this, i18n("Unable to modify this to-do item, "
+        KMessageBox::sorry( this, i18n("Unable to modify this to-do, "
                             "because it cannot be locked.") );
       }
       delete oldTodo;
