@@ -19,7 +19,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -99,7 +99,7 @@ const int KODayMatrix::NOSELECTION = -1000;
 const int KODayMatrix::NUMDAYS = 42;
 
 KODayMatrix::KODayMatrix( QWidget *parent, const char *name )
-  : QFrame( parent, name ), mCalendar( 0 )
+  : QFrame( parent, name ), mCalendar( 0 ), mStartDate( 1970, 1, 1 )
 {
   // initialize dynamic arrays
   mDays = new QDate[ NUMDAYS ];
@@ -110,6 +110,7 @@ KODayMatrix::KODayMatrix( QWidget *parent, const char *name )
   mTodayMarginWidth = 2;
   mSelEnd = mSelStart = NOSELECTION;
   setBackgroundMode( NoBackground );
+  recalculateToday();
 }
 
 void KODayMatrix::setCalendar( Calendar *cal )
@@ -243,6 +244,9 @@ void KODayMatrix::updateView( const QDate &actdate )
     recalculateToday();
   }
 
+  // TODO_Recurrence: If we just change the selection, but not the data, there's
+  // no need to update the whole list of events... This is just a waste of
+  // computational power (and it takes forever!)
   updateEvents();
   for( int i = 0; i < NUMDAYS; i++ ) {
     //if it is a holy day then draw it red. Sundays are consider holidays, too
@@ -270,8 +274,7 @@ void KODayMatrix::updateEvents()
     Event::List::ConstIterator it;
     for( it = eventlist.begin(); it != eventlist.end(); ++it ) {
       Event *event = *it;
-      ushort recurType = event->doesRecur();
-
+      ushort recurType = event->recurrenceType();
       if ( ( recurType == Recurrence::rDaily &&
              !KOPrefs::instance()->mDailyRecur ) ||
            ( recurType == Recurrence::rWeekly &&
@@ -473,13 +476,13 @@ void KODayMatrix::dropEvent( QDropEvent *e )
   if ( action == DRAG_COPY  || action == DRAG_MOVE ) {
     e->accept();
     int idx = getDayIndexFrom( e->pos().x(), e->pos().y() );
-    
+
     if ( action == DRAG_COPY ) {
       if ( event ) emit incidenceDropped( event, mDays[idx] );
-      if ( todo )  emit incidenceDropped( event, mDays[idx] );
+      if ( todo )  emit incidenceDropped( todo, mDays[idx] );
     } else if ( action == DRAG_MOVE ) {
       if ( event ) emit incidenceDroppedMove( event, mDays[idx] );
-      if ( todo )  emit incidenceDroppedMove( event, mDays[idx] );
+      if ( todo )  emit incidenceDroppedMove( todo, mDays[idx] );
     }
   }
   delete event;
@@ -519,26 +522,33 @@ void KODayMatrix::paintEvent( QPaintEvent * )
   if (mSelStart != NOSELECTION) {
 
     row = mSelStart/7;
+    // fix larger selections starting in the previous month
+    if ( row < 0 && mSelEnd > 0 ) row = 0;
     col = mSelStart -row*7;
     QColor selcol = KOPrefs::instance()->mHighlightColor;
 
-    if (row == mSelEnd/7) {
-      // Single row selection
-      p.fillRect(isRTL ? (7 - (mSelEnd-mSelStart+1) - col)*dwidth : col*dwidth,
-                  row*dheight, (mSelEnd-mSelStart+1)*dwidth, dheight, selcol);
-    } else {
-      // draw first row to the right
-      p.fillRect(isRTL ? 0 : col*dwidth, row*dheight, (7-col)*dwidth,
-                 dheight, selcol);
-      // draw full block till last line
-      selh = mSelEnd/7-row;
-      if (selh > 1) {
-        p.fillRect(0, (row+1)*dheight, 7*dwidth, (selh-1)*dheight,selcol);
+    if ( row < 6 && row >= 0 ) {
+      if (row == mSelEnd/7) {
+        // Single row selection
+        p.fillRect(isRTL ? (7 - (mSelEnd-mSelStart+1) - col)*dwidth : col*dwidth,
+                    row*dheight, (mSelEnd-mSelStart+1)*dwidth, dheight, selcol);
+      } else {
+        // draw first row to the right
+        p.fillRect(isRTL ? 0 : col*dwidth, row*dheight, (7-col)*dwidth,
+                   dheight, selcol);
+        // draw full block till last line
+        selh = mSelEnd/7-row;
+        if ( selh + row >= 6 ) selh = 6-row;
+        if ( selh > 1 ) {
+          p.fillRect(0, (row+1)*dheight, 7*dwidth, (selh-1)*dheight,selcol);
+        }
+        // draw last block from left to mSelEnd
+        if ( mSelEnd/7 < 6 ) {
+          selw = mSelEnd-7*(mSelEnd/7)+1;
+          p.fillRect(isRTL ? (7-selw)*dwidth : 0, (row+selh)*dheight,
+                     selw*dwidth, dheight, selcol);
+        }
       }
-      // draw last block from left to mSelEnd
-      selw = mSelEnd-7*(mSelEnd/7)+1;
-      p.fillRect(isRTL ? (7-selw)*dwidth : 0, (row+selh)*dheight,
-                 selw*dwidth, dheight, selcol);
     }
   }
 
