@@ -345,7 +345,7 @@ void RecurMonthly::setByDay( int day )
   mByDayRadio->setChecked( true );
   // Days from the end are after the ones from the begin, so correct for the
   // negative sign and add 30 (index starting at 0)
-  if ( day > 0 & day <= 31 )
+  if ( day > 0 && day <= 31 )
     mByDayCombo->setCurrentItem( day-1 );
   else if ( day < 0 )
     mByDayCombo->setCurrentItem( 31 - 1 - day );
@@ -1165,7 +1165,7 @@ void KOEditorRecurrence::setDefaults( const QDateTime &from, const QDateTime &to
   mWeekly->setDays( days );
 
   mMonthly->setFrequency( 1 );
-  mMonthly->setByPos( ( from.date().day() - 1 ) / 7 + 1, from.date().dayOfWeek() - 1 );
+  mMonthly->setByPos( ( from.date().day() - 1 ) / 7 + 1, from.date().dayOfWeek() );
   mMonthly->setByDay( from.date().day() );
 
   mYearly->setFrequency( 1 );
