@@ -262,8 +262,7 @@ void MonthViewItem::paint( QPainter *p )
     yPos = fm.ascent() + fm.leading()/2;
   else
     yPos = pmheight/2 - fm.height()/2  + fm.ascent();
-  QColor textColor = palette().color( QPalette::Normal, sel ? \
-          QColorGroup::HighlightedText : QColorGroup::Text );
+  QColor textColor = getTextColor( bgColor );
   p->setPen( textColor );
 
   KWordWrap::drawFadeoutText( p, x, yPos, listBox()->width() - x, text() );
@@ -439,11 +438,12 @@ class MonthViewCell::CreateItemVisitor :
   public:
     CreateItemVisitor() : mItem(0) { emails = KOPrefs::instance()->allEmails(); }
 
-    bool act( IncidenceBase *incidence, QDate date, QPalette stdPal )
+    bool act( IncidenceBase *incidence, QDate date, QPalette stdPal, int multiDay )
     {
       mItem = 0;
       mDate = date;
       mStandardPalette = stdPal;
+      mMultiDay = multiDay;
       return incidence->accept( *this );
     }
     MonthViewItem *item() const { return mItem; }
@@ -453,13 +453,19 @@ class MonthViewCell::CreateItemVisitor :
     bool visit( Event *event ) {
       QString text;
       QDateTime dt( mDate );
+      // take the time 0:00 into account, which is non-inclusive
+      QDate dtEnd = event->dtEnd().addSecs( event->doesFloat() ? 0 : -1).date();
+      int length = event->dtStart().daysTo( dtEnd );
       if ( event->isMultiDay() ) {
-        if (mDate == event->dtStart().date()) {
+        if (  mDate == event->dtStart().date()
+           || ( mMultiDay == 0 && event->recursOn( mDate ) ) ) {
           text = "(-- " + event->summary();
           dt = event->dtStart();
-        } else if (mDate == event->dtEnd().date()) {
+        } else if ( !event->doesRecur() && mDate == dtEnd
+                 // last day of a recurring multi-day event?
+                 || ( mMultiDay == length && event->recursOn( mDate.addDays( -length ) ) ) ) {
           text = event->summary() + " --)";
-        } else if (!(event->dtStart().date().daysTo(mDate) % 7)) {
+        } else if (!(event->dtStart().date().daysTo(mDate) % 7) && length > 7 ) {
           text = "-- " + event->summary() + " --";
         } else {
           text = "----------------";
@@ -471,7 +477,7 @@ class MonthViewCell::CreateItemVisitor :
         else {
           text = KGlobal::locale()->formatTime(event->dtStart().time());
           dt.setTime( event->dtStart().time() );
-          text += " " + event->summary();
+          text += ' ' + event->summary();
         }
       }
 
@@ -502,13 +508,12 @@ class MonthViewCell::CreateItemVisitor :
       QDateTime dt( mDate );
       if ( todo->hasDueDate() && !todo->doesFloat() ) {
         text += KGlobal::locale()->formatTime( todo->dtDue().time() );
-        text += " ";
+        text += ' ';
         dt.setTime( todo->dtDue().time() );
       }
       text += todo->summary();
 
       mItem = new MonthViewItem( todo, dt, text );
-// FIXME: This breaks with recurring multi-day events!
       if ( todo->doesRecur() ) {
         mDate < todo->dtDue().date() ?
         mItem->setTodoDone( true ) : mItem->setTodo( true );
@@ -522,12 +527,13 @@ class MonthViewCell::CreateItemVisitor :
     MonthViewItem *mItem;
     QDate mDate;
     QPalette mStandardPalette;
+    int mMultiDay;
 };
 
 
-void MonthViewCell::addIncidence( Incidence *incidence, CreateItemVisitor& v)
+void MonthViewCell::addIncidence( Incidence *incidence, CreateItemVisitor& v, int multiDay )
 {
-  if ( v.act( incidence, mDate, mStandardPalette ) ) {
+  if ( v.act( incidence, mDate, mStandardPalette, multiDay ) ) {
     MonthViewItem *item = v.item();
     if ( item ) {
       item->setAlarm( incidence->isAlarmEnabled() );
@@ -558,18 +564,16 @@ void MonthViewCell::addIncidence( Incidence *incidence, CreateItemVisitor& v)
   }
 }
 
-bool MonthViewCell::removeIncidence( Incidence *incidence )
+void MonthViewCell::removeIncidence( Incidence *incidence )
 {
-  for ( uint i = 0; i < mItemList->count(); i++ ) {
+  for ( uint i = 0; i < mItemList->count(); ++i ) {
     MonthViewItem *item = static_cast<MonthViewItem *>(mItemList->item( i ) );
     if ( item && item->incidence() &&
          item->incidence()->uid() == incidence->uid() ) {
       mItemList->removeItem( i );
-      return true;
+      --i;
     }
   }
-
-  return false;
 }
 
 void MonthViewCell::updateConfig()
@@ -649,7 +653,7 @@ QDate MonthViewCell::selectedIncidenceDate()
 
 void MonthViewCell::select()
 {
-  // setSelectedCall will deselect currently selected cells
+  // setSelectedCell will deselect currently selected cells
   mMonthView->setSelectedCell( this );
 
   if( KOPrefs::instance()->enableMonthScroll() )
@@ -860,6 +864,8 @@ void KOMonthView::showDates( const QDate &start, const QDate & )
 
   const KCalendarSystem *calSys = KOGlobals::self()->calendarSystem();
 
+  mDateToCell.clear();
+
   // show first day of month on top for readability issues
   mStartDate = start.addDays( -start.day() + 1 );
   // correct begin of week
@@ -879,6 +885,7 @@ void KOMonthView::showDates( const QDate &start, const QDate & )
     }
 
     mCells[i]->setDate( date );
+    mDateToCell[ date ] = mCells[ i ];
     if( date == start )
       mCells[i]->select();
 
@@ -910,63 +917,63 @@ class KOMonthView::GetDateVisitor : public IncidenceBase::Visitor
     {
       return incidence->accept( *this );
     }
-    QDate date() const { return mDate; }
+    QDateTime startDate() const { return mStartDate; }
+    QDateTime endDate() const { return mEndDate; }
 
   protected:
     bool visit( Event *event ) {
-      mDate = event->dtStart().date();
+      mStartDate = event->dtStart();
+      mEndDate = event->dtEnd();
       return true;
     }
     bool visit( Todo *todo ) {
       if ( todo->hasDueDate() ) {
-        mDate = todo->dtDue().date();
+        mStartDate = todo->dtDue();
+        mEndDate = todo->dtDue();
         return true;
       } else
         return false;
     }
     bool visit( Journal *journal ) {
-      mDate = journal->dtStart().date();
+      mStartDate = journal->dtStart();
+      mEndDate = journal->dtStart();
       return true;
     }
   protected:
-    QDate mDate;
+    QDateTime mStartDate;
+    QDateTime mEndDate;
 };
 
 void KOMonthView::changeIncidenceDisplayAdded( Incidence *incidence, MonthViewCell::CreateItemVisitor& v)
 {
-  MonthViewCell *mvc;
-  Event *event = 0;
-  Todo *todo = 0;
-  QDate date;
+  GetDateVisitor gdv;
 
-  // FIXME: use a visitor here
-  if ( incidence->type() == "Event" ) {
-    event = static_cast<Event *>( incidence );
-    date = event->dtStart().date();
-  }
-  if ( incidence->type() == "Todo" ) {
-    todo = static_cast<Todo *>( incidence );
-    if ( !todo->hasDueDate() ) return;
-    date = todo->dtDue().date();
+  if ( !gdv.act( incidence ) ) {
+    kdDebug(5850) << "Visiting GetDateVisitor failed." << endl;
+    return;
   }
 
+  bool floats = incidence->doesFloat();
+
   if ( incidence->doesRecur() ) {
-// FIXME: This breaks with recurring multi-day events!
-     for ( uint i = 0; i < mCells.count(); i++ ) {
-       if ( incidence->recursOn( mCells[i]->date() ) ) {
-         mCells[i]->addIncidence( incidence, v );
-       }
-     }
-  } else if ( event ) {
-      for ( QDateTime _date = date;
-            _date <= event->dtEnd(); _date = _date.addDays( 1 ) ) {
-        mvc = lookupCellByDate( _date.date() );
-        if ( mvc ) mvc->addIncidence( event, v );
-      }
-    } else if ( todo ) {
-        mvc = lookupCellByDate( date );
-        if ( mvc ) mvc->addIncidence( todo, v );
+    for ( uint i = 0; i < mCells.count(); ++i ) {
+      if ( incidence->recursOn( mCells[i]->date() ) ) {
+
+        // handle multiday events
+        int length = gdv.startDate().daysTo( gdv.endDate().addSecs( floats ? 0 : -1 ).date() );
+        for ( int j = 0; j <= length && i+j < mCells.count(); ++j ) {
+          mCells[i+j]->addIncidence( incidence, v, j );
+        }
       }
+    }
+  } else {
+    // addSecs(-1) is added to handle 0:00 cases (because it's non-inclusive according to rfc)
+    QDate endDate = gdv.endDate().addSecs( floats ? 0 : -1).date();
+    for ( QDate date = gdv.startDate().date(); date <= endDate; date = date.addDays( 1 ) ) {
+      MonthViewCell *mvc = mDateToCell[ date ];
+      if ( mvc ) mvc->addIncidence( incidence, v );
+    }
+  }
 }
 
 void KOMonthView::changeIncidenceDisplay( Incidence *incidence, int action )
@@ -1037,9 +1044,8 @@ void KOMonthView::showGeneralContextMenu()
 
 void KOMonthView::setSelectedCell( MonthViewCell *cell )
 {
-  if ( cell == mSelectedCell ) return;
-
-  if ( mSelectedCell ) mSelectedCell->deselect();
+  if ( mSelectedCell && cell != mSelectedCell )
+    mSelectedCell->deselect();
 
   mSelectedCell = cell;
 
@@ -1066,12 +1072,3 @@ void KOMonthView::clearSelection()
     mSelectedCell = 0;
   }
 }
-
-MonthViewCell *KOMonthView::lookupCellByDate ( const QDate &date )
-{
-  for( uint i = 0; i < mCells.count(); i++ ) {
-    if ( mCells[i]->date() == date )
-      return mCells[i];
-  }
-  return 0;
-}
