@@ -22,15 +22,15 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
 ** Bug reports and questions can be sent to kde-pim@kde.org
 */
 
-static const char *vcalconduitbase_id = "$Id: vcal-conduitbase.cc 412940 2005-05-12 23:32:07Z adridg $";
+static const char *vcalconduitbase_id = "$Id: vcal-conduitbase.cc 450417 2005-08-18 06:07:11Z vanrijn $";
 
 #include <options.h>
 
@@ -471,12 +471,17 @@ void VCalConduitBase::slotPCRecToPalm()
 	if (!e)
 	{
 		pilotindex=0;
-		if ( (syncMode()==SyncMode::eCopyHHToPC) || (syncMode()==SyncMode::eCopyPCToHH) )
+		// if we are asked to copy HH to PC, we shouldn't look for deleted records
+		// on the Palm, since we've just copied them all.  =:)  Otherwise, look for
+		// data on the palm that shouldn't be there and delete it if we find it....
+		if ( syncMode()==SyncMode::eCopyHHToPC )
 		{
 			QTimer::singleShot(0, this, SLOT(cleanup()));
-			return;
 		}
-		QTimer::singleShot(0,this,SLOT(slotDeletedIncidence()));
+		else
+		{
+			QTimer::singleShot(0,this,SLOT(slotDeletedIncidence()));
+		}
 		return;
 	}
 
@@ -521,7 +526,7 @@ void VCalConduitBase::slotDeletedIncidence()
 	FUNCTIONSETUP;
 
 	PilotRecord *r = fLocalDatabase->readRecordByIndex(pilotindex++);
-	if (!r || isFullSync() )
+	if (!r || (syncMode()==SyncMode::eCopyHHToPC) )
 	{
 		QTimer::singleShot(0 ,this,SLOT(cleanup()));
 		return;
@@ -678,11 +683,14 @@ KCal::Incidence*VCalConduitBase::changeRecord(PilotRecord *r,PilotRecord *)
 
 	PilotAppCategory*de=newPilotEntry(r);
 	KCal::Incidence *e = fP->findIncidence(r->id());
+#ifdef DEBUG
+	DEBUGCONDUIT<<fname<<": Pilot Record ID: ["<<r->id() << "]" <<endl;
+#endif
 
 	if (e && de)
 	{
 		// TODO: check for conflict, and if there is one, ask for resolution
-		if ( (e->syncStatus()!=KCal::Incidence::SYNCNONE) && (r->getAttrib() &dlpRecAttrDirty) )
+		if ( (e->syncStatus()!=KCal::Incidence::SYNCNONE) && (r->isDirty() ) )
 		{
 			// TODO: I have not yet found a way to complete ignore an item
 			if (resolveConflict(e, de))
