@@ -22,15 +22,15 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
 ** Bug reports and questions can be sent to kde-pim@kde.org.
 */
 static const char *test_id =
-	"$Id: main-test.cc 412940 2005-05-12 23:32:07Z adridg $";
+	"$Id: main-test.cc 449698 2005-08-16 13:24:56Z adridg $";
 
 #include "options.h"
 
@@ -95,6 +95,9 @@ static KCmdLineOptions kpilotoptions[] = {
 	{ "test-usercheck",
 		I18N_NOOP("Run conduit just for user check."),
 		0 } ,
+	{ "dump-calendar",
+		I18N_NOOP("Dump calendar to stdout."),
+		0 } ,
 #ifdef DEBUG
 	{"debug <level>", I18N_NOOP("Set debugging level"), "0"},
 #endif
@@ -191,15 +194,16 @@ void connectStack()
 		logWidget, SLOT(addMessage(const QString &)));
 	QObject::connect(syncStack,SIGNAL(logProgress(const QString &,int)),
 		logWidget, SLOT(addProgress(const QString &,int)));
-
-	QObject::connect(deviceLink, SIGNAL(deviceReady(KPilotDeviceLink*)), syncStack, SLOT(execConduit()));
-
 	QObject::connect(syncStack, SIGNAL(syncDone(SyncAction *)),
 		logWidget, SLOT(syncDone()));
-	QObject::connect(syncStack, SIGNAL(syncDone(SyncAction *)),
-		deviceLink, SLOT(close()));
 
-	QObject::connect(resetButton,SIGNAL(clicked()),deviceLink,SLOT(reset()));
+	if (deviceLink)
+	{
+		QObject::connect(syncStack, SIGNAL(syncDone(SyncAction *)),
+			deviceLink, SLOT(close()));
+		QObject::connect(deviceLink, SIGNAL(deviceReady(KPilotDeviceLink*)), syncStack, SLOT(execConduit()));
+		QObject::connect(resetButton,SIGNAL(clicked()),deviceLink,SLOT(reset()));
+	}
 }
 
 void createConnection(KCmdLineArgs *p)
@@ -264,20 +268,33 @@ int execConduit(KCmdLineArgs *p)
 	l.append(s);
 
 	createLogWidget();
-	createLink();
 
 	SyncAction::SyncMode::Mode syncMode = SyncAction::SyncMode::eHotSync;
 	if (p->isSet("HHtoPC")) syncMode = SyncAction::SyncMode::eCopyHHToPC;
 	if (p->isSet("PCtoHH")) syncMode = SyncAction::SyncMode::eCopyPCToHH;
-
 	SyncAction::SyncMode mode(syncMode,p->isSet("test"),p->isSet("local"));
-	syncStack = new ActionQueue(deviceLink);
-	syncStack->queueInit();
-	syncStack->queueConduits(l,mode,false);
-	syncStack->queueCleanup();
 
-	connectStack();
-	createConnection(p);
+	if (!p->isSet("local"))
+	{
+		createLink();
+
+		syncStack = new ActionQueue(deviceLink);
+		syncStack->queueInit();
+		syncStack->queueConduits(l,mode,false);
+		syncStack->queueCleanup();
+		connectStack();
+		createConnection(p);
+	}
+	else
+	{
+		syncStack = new ActionQueue( 0L );
+		syncStack->queueInit();
+		syncStack->queueConduits(l,mode,false);
+		syncStack->queueCleanup();
+		connectStack();
+		QTimer::singleShot(100,syncStack,SLOT(execConduit()));
+	}
+
 
 	return kapp->exec();
 }
