@@ -684,7 +684,9 @@ void KCalResourceSlox::parseIncidenceAttribute( const QDomElement &e,
       incidence->clearAlarms();
     }
   } else if ( tag == fieldName( CreatedBy ) ) {
-    KABC::Addressee a = mAccounts->lookupUser( text );
+    KABC::Addressee a;
+    if ( mAccounts ) a = mAccounts->lookupUser( text );
+    else kdDebug() << "KCalResourceSlox: no accounts set" << endl;
     incidence->setOrganizer( Person( a.formattedName(), a.preferredEmail() ) );
   } else if ( tag == fieldName( Participants ) ) {
     parseMembersAttribute( e, incidence );
