@@ -7,15 +7,15 @@
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
-    
+
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 #ifndef SLOXACCOUNTS_H
 #define SLOXACCOUNTS_H
@@ -28,17 +28,19 @@ namespace KIO {
 class Job;
 }
 
+class SloxBase;
+
 class KDE_EXPORT SloxAccounts : public QObject
 {
     Q_OBJECT
   public:
-    SloxAccounts( const KURL &baseUrl );
+    SloxAccounts( SloxBase *res, const KURL &baseUrl );
     ~SloxAccounts();
 
     void insertUser( const QString &id, const KABC::Addressee &a );
-  
+
     KABC::Addressee lookupUser( const QString &id );
-  
+
     QString lookupId( const QString &email );
 
   protected:
@@ -46,10 +48,10 @@ class KDE_EXPORT SloxAccounts : public QObject
     void readAccounts();
 
     QString cacheFile() const;
-    
+
   protected slots:
     void slotResult( KIO::Job * );
-  
+
   private:
     QString mDomain;
 
@@ -58,6 +60,7 @@ class KDE_EXPORT SloxAccounts : public QObject
     QMap<QString, KABC::Addressee> mUsers; // map users ids to addressees.
 
     KURL mBaseUrl;
+    SloxBase *mRes;
 };
 
 #endif
