@@ -634,8 +634,8 @@ Base6::parseKeyData( const QCString& output, int& offset, Key* key /* = 0 */ )
         }
       }
       // store the global key capabilities
-      canSign |= sign;
-      canEncr |= encr;
+      canSign = canSign || sign;
+      canEncr = canEncr || encr;
     }
     else if( !strncmp( output.data() + offset, "Unknown type", 12 ) )
     { // line contains key data of unknown type (ignored)
