@@ -3,8 +3,8 @@
 // Contents:   Definitions for DwString
 // Maintainer: Doug Sauder <dwsauder@fwb.gulf.net>
 // WWW:        http://www.fwb.gulf.net/~dwsauder/mimepp.html
-// $Revision: 386818 $
-// $Date: 2005-02-06 19:06:57 +0100 (So, 06 Feb 2005) $
+// $Revision: 423737 $
+// $Date: 2005-06-09 16:41:43 +0200 (Do, 09 Jun 2005) $
 //
 // Copyright (c) 1996, 1997 Douglas W. Sauder
 // All rights reserved.
@@ -310,7 +310,7 @@ void DwStringRep::operator delete(void* aRep, size_t)
 
 const size_t DwString::kEmptyBufferSize = 4;
 char DW_EXPORT DwString::sEmptyBuffer[]="    ";
-DwStringRep* DW_EXPORT DwString::sEmptyRep = 0;
+DwStringRep* DwString::sEmptyRep = 0;
 
 const size_t DwString::npos = (size_t) -1;
 
